/**
 * Contains a mapping from scene name to scene folder.
 */
function SceneMap() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var folderMap = {
        "Introduction": "",
        "Forest": "",
        "Home": "",
        "ForestRiver": "ForestToVaranar",
        "SekiWorkshop": "HamletDay2",
        "BreedingFarm": "HamletDay2",
        "FarmerHouse": "HamletDay2",
        "HamletWell": "HamletDay2",
        "UndergroundCave": "HamletDay2",
        "NightTwo": "Varanar",
        "MorningThree": "Varanar/DayThree",
        "NoonThreeStore": "Varanar/DayThree",
        "AfternoonThree": "Varanar/DayThree",
        "VaranarSoupKitchen": "Varanar/DayThree",
        "CaravanConfinement": "Enslavement",
        "SlaveNoonTwo": "Enslavement/DayTwo",
        "FarmerMaid": "Enslavement/DayTwo",
        "RiversideMarsh": "Deepwoods"
    };

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Returns the foldermap. You probably shouldn't alter anything in it, though.
     * @returns {object} The foldermap.
     */
    this.get = function () {
        return folderMap;
    };

    /**
     * Returns all of the scenes in the foldermap, without their folders.
     * @returns {array} An array containing all the scene names.
     */
    this.getAll = function () {
        return Object.keys(folderMap);
    };

    /**
     * Returns true if the passed scene exists, false otherwise.
     * @param {string} scene The scene to check.
     * @returns {boolean} True if the passed scene exists, false otherwise.
     */
    this.exists = function (scene) {
        return scene in folderMap;
    };

    /**
     * Constructs the path to the base folder of the scene with the given id.
     * @param {string} id The id of the scene for which to construct the folder path.
     * @returns {string} The base folder path for the scene with the given id.
     */
    this.constructFolderPath = function (id) {
        var folder = folderMap[id] || "";
        if (folder) {
            return `scenes/${folder}/${id}/`;
        } else {
            return `scenes/${id}/`;
        }
    };

    /**
     * Constructs the path to the JSON file of the scene with the given id.
     * @param {string} id The id of the scene for which to construct the JSON file path.
     * @returns {string} The JSON file path for the scene with the given id.
     */
    this.constructJsonPath = function (id) {
        return that.constructFolderPath(id) + `${id}.json`;
    };

    /**
     * For each entry in the folder map, constructs a path to the JSON file and adds it to an array.
     * @returns {array} The JSON path array.
     */
    this.constructJsonPathArray = function () {
        var jsonPathArray = {};
        for (var id in folderMap) {
            jsonPathArray[id] = that.constructJsonPath(id);
        }
        return jsonPathArray;
    };

}
