/**
 * The Fish class represents a raw fish that can be consumed by the kobold,
 * which increases its statuses.
 */
function Fish() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Fish";
    var itemDescription = "A raw fish, of questionable age. At least it's not [i]completely[/i] rotten yet.";
    var baseValue = 3;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You sniff the fish.
                            It doesn't smell too good.
                            It's been at least a few days since this has been caught, and you don't think it's been kept in the best of conditions since.
                            Steeling your mind by remembering that you've had [b]far[/b] worse meals than this,
                            you part your lips, and sink your teeth into the dead, aquatical creature.
                        [/p]
                        [p]
                            You [b]tear[/b] off over half of the spoilt corpse's side,
                            chewing through the tough, unsavory scales.
                            Your first bite having ripped off the tough exterior,
                            your second dip allows you to tear into the squishy insides, where all the good bits are.
                            You yank out a few bloody organs along with some of the meat, chew the mixture thoroughly, then swallow down.
                        [/p]
                        [p]
                            Definitely [b]long[/b] overdue,
                            but you'd rather have a spoiled meal than none at all.
                            You power on, chewing through the insides, making sure not to swallow any of the small bones.
                            Nearing the end of your meal, you start to feel kind of [i]unwell[/i].
                            You decide not to eat the remaining few pieces, instead discarding the rotten, half-eaten fish.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.FISH;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.decrease(2, "Ate a raw fish");
        global.kobold.status.mental.decrease(2, "Ate a raw fish");
        global.kobold.status.stamina.increase(3, "Ate a raw fish");
        global.kobold.status.exertion.decrease(3, "Ate a raw fish");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", -2),
            new Change("Food", "Sanity", -2),
            new Change("Food", "Stamina", +3),
            new Change("Food", "Sexual exhaustion", -3, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Consumable-stripped} consumable A Consumable object, stripped of private members and all functions.
     */
    this.load = function (consumable) {

    };
}
