/**
 * The BeefUp class represents a potion that can be consumed by the kobold,
 * which increases its strength, but lowers its luck.
 */
function BeefUp() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "BeefUp Potion";
    var itemDescription = `A glass bottle filled to the brim with a shiny-looking grey goop.
                           Promises to make you stronger.`;
    var baseValue = 25;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion.
                            It smells pretty [i]neutral[/i].
                            A slightly [i]metallic[/i] fragrance.
                            Odd.
                            Bracing for the worst, you bring the vial to your lips, and chug down.
                        [/p]
                        [p]
                            Iron.
                            It's pure, thick, liquid iron.
                            All of your instincts tell you that you [b]shouldn't[/b] be drinking this.
                            That it's [b]bad[/b] for your wellbeing.
                            That you should go [b]work out[/b] instead of [b]poisoning[/b] yourself.
                            But you don't have time for that.
                            You [b]need[/b] to grow stronger, and quick.
                        [/p]
                        [p]
                            You chug down the remainder of the flask,
                            your gut growing [b]heavy[/b] with metallic contents.
                            This is going to make you [b]sick[/b].
                            Barely refraining from throwing up the toxic sludge,
                            you can feel it starting to affect your muscles.
                        [/p]
                        [p]
                            Your arms and legs grow slightly heavier, as though your limbs are being [b]reinforced[/b] by the iron you drank.
                            You'd expect this to make you more [i]sturdy[/i], but instead the drink acts as a pseudo-steroid,
                            empowering only your muscles, making you stronger while leaving the rest of your body every bit as [i]sensitive[/i] as before. 
                            You get the feeling that, with this much metal in your body, you'll be at risk of getting struck during a lightning storm.
                        [/p]
                        [p]
                            [b]You have gained 1 strength.[/b][nl]
                            [warn][b]You have lost 1 luck.[/b][/warn]
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as strong as you're ever going to get.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when minned out.
     * @returns {string} The consume popup contents when minned out.
     */
    function buildMinContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are't lucky enough to drink something like this and survive.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.BEEFUP;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var str = global.kobold.stats.get(StatsEnum.STRENGTH);
        var lck = global.kobold.stats.get(StatsEnum.LUCK);
        var maxed = (str >= global.kobold.stats.statMax);
        var minned = (lck <= global.kobold.stats.statMin);
        if (maxed) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMaxContents()));
            return false;
        }
        if (minned) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMinContents()));
            return false;
        } else {
            global.kobold.stats.increaseStat(StatsEnum.STRENGTH, 1);
            global.kobold.stats.decreaseStat(StatsEnum.LUCK, 1);
            global.ui.showFullscreenPopup(buildPopupContents());
        }
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Potion-stripped} potion A Potion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
