/**
 * The LiquidLuck class represents a potion that can be consumed by the kobold,
 * which increases its luck, but lowers its agility.
 */
function LiquidLuck() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "LiquidLuck Potion";
    var itemDescription = `A glass bottle filled to the brim with a clear, water-like fluid.
                           Promises to make you more lucky.`;
    var baseValue = 25;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion.
                            It smells like water.
                            It looks like water.
                            You're starting to think this might be a scam.
                        [/p]
                        [p]
                            Shrugging, you gulp down the contents of the vial.
                            Water.
                            It's just water.
                            Is this one of those "it makes you believe in yourself" types of deals?
                            That's nonsense!
                            You feel cheated!
                        [/p]
                        [p]
                            Suddenly, an awkwardly [b]sluggish[/b] sensation washes over you.
                            Your mind and your body both feel [b]slower[/b].
                            Was the water [b]spiked[/b] with something?!
                            You take a seat on the ground for a minute, to recover.
                            Your head is spinning.
                            You nearly pass out.
                        [/p]
                        [p]
                            As quickly as the feeling appeared, so too does the worst of it it fade in a matter of moments.
                            As your mind sharpens once more, you are left feeling unexplicably [i]luckier[/i].
                            Not ordinary water after all, you suppose.
                            Rising to your feet, however, it seems as though part of the [i]sluggishness[/i] persists.
                            You shrug it off, thinking you'll feel better in a bit.
                            [sneak]You won't.[/sneak]
                        [/p]
                        [p]
                            [b]You have gained 1 luck.[/b][nl]
                            [warn][b]You have lost 1 agility.[/b][/warn]
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as lucky as you're ever going to get.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when minned out.
     * @returns {string} The consume popup contents when minned out.
     */
    function buildMinContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You feel so sluggish, that you can't even lift the potion to your lips.
                            You do not drink it.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.LIQUIDLUCK;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var lck = global.kobold.stats.get(StatsEnum.LUCK);
        var agi = global.kobold.stats.get(StatsEnum.AGILITY);
        var maxed = (lck >= global.kobold.stats.statMax);
        var minned = (agi <= global.kobold.stats.statMin);
        if (maxed) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMaxContents()));
            return false;
        }
        if (minned) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMinContents()));
            return false;
        } else {
            global.kobold.stats.increaseStat(StatsEnum.LUCK, 1);
            global.kobold.stats.decreaseStat(StatsEnum.AGILITY, 1);
            global.ui.showFullscreenPopup(buildPopupContents());
        }
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Potion-stripped} potion A Potion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
