/**
 * This class represents a weapon that can be used by the kobold.
 */
function Mace() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Mace";
    var rustedItemName = "Rusted Mace";
    var itemDescription = "A blunt weapon. Undersized and slightly bent out of shape. You think something went wrong while forging this tool of war.";
    var rustedItemDescription = "A completely rusted mace. Useless.";
    var baseValue = 30;
    var offensiveValue = 5;
    var defensiveValue = 3;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.MACE;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.GEAR;
    // GEAR-REQUIRED slot-enum.
    this.slot = SlotEnum.WEAPON;

    // Whether or not the weapon is rusted.
    this.isRusted = false;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        if (that.isRusted) {
            toReturn = caps ? rustedItemName : rustedItemName.toLowerCase();
        }
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        if (that.isRusted) {
            return rustedItemDescription;
        }
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        if (that.isRusted) {
            return baseValue - 25;
        }
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 225px;";
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the offensive value of this piece of gear.
     * @returns {int} The offensive value of this piece of gear.
     */
    this.offence = function () {
        if (that.isRusted) {
            return 1;
        }
        return offensiveValue;
    };

    /**
     * GEAR-REQUIRED function.
     * Calculates and returns the defensive value of this piece of gear.
     * @returns {int} The defensive value of this piece of gear.
     */
    this.defence = function () {
        if (that.isRusted) {
            return 1;
        }
        return defensiveValue;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon is ranged.
     * @returns {boolean} Whether or not this weapon is ranged.
     */
    this.ranged = function () {
        return that.throw() || that.shoot();
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon can be thrown.
     * @returns {boolean} Whether or not this weapon can be thrown.
     */
    this.throw = function () {
        return false;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon can be shot.
     * @returns {boolean} Whether or not this weapon can be shot.
     */
    this.shoot = function () {
        return false;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon is a blunt melee weapon.
     * @returns {boolean} Whether or not this weapon is a blunt melee weapon.
     */
    this.blunt = function () {
        return true;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon is a slashing melee weapon.
     * @returns {boolean} Whether or not this weapon is a slashing melee weapon.
     */
    this.slash = function () {
        return false;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon is a stabbing melee weapon.
     * @returns {boolean} Whether or not this weapon is a stabbing melee weapon.
     */
    this.stab = function () {
        return false;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns true if this weapon can rust, false otherwise.
     * @returns {boolean} True if this weapon can rust, false otherwise.
     */
    this.canRust = function () {
        return true;
    };

    /**
     * WEAPON-REQUIRED function.
     * Rusts this weapon.
     */
    this.rust = function () {
        that.isRusted = true;
    };

    /**
     * WEAPON-REQUIRED function.
     * Returns whether or not this weapon is rusted.
     * @returns {boolean} True if this weapon is rusted, false otherwise.
     */
    this.rusted = function () {
        return that.isRusted;
    };

    /**
     * WEAPON-REQUIRED function.
     * Uses this weapon for melee combat.
     */
    this.useMelee = function () {

    };

    /**
     * WEAPON-REQUIRED function.
     * Uses this weapon for ranged combat.
     */
    this.useRanged = function () {

    };

    /**
     * WEAPON-REQUIRED function.
     * Returns how many uses this weapon has left.
     * @returns {int} How many uses this weapon has left.
     */
    this.usesLeft = function () {
        return 99;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Weapon-stripped} weapon A Weapon, stripped of private members and all functions.
     */
    this.load = function (weapon) {
        that.isRusted = weapon.isRusted;
    };
}
