/**
 * The global mute button in the bottom right of the left-hand sidebar.
 * Its init() function should be called immediately upon successful project load.
 */
function GlobalMuteButton() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var muteButtonId = "globalmute";
    var onClass = "globalmuteon";
    var offClass = "globalmuteoff";

    var audioEnabled = true;
    var soundMuted = true;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Registers the button listener for the menu button.
     */
    function registerListeners() {
        $("#" + muteButtonId).click(that.toggleMute);
    }
    
    /**
     * Updates the audio setting.
     */
    function updateAudio() {
        if(soundMuted) {
            global.audio.mute();
        } else {
            global.audio.unmute();
        }
    }

    /**
     * Updates the global mute setting.
     */
    function updateSetting() {
        global.settings.setGlobalMute(soundMuted);
    }

    /**
     * Updates the class of the mute div to reflect whether or not the sound is muted.
     */
    function updateClass() {
        if (soundMuted) {
            $("#" + muteButtonId).removeClass(offClass);
            $("#" + muteButtonId).addClass(onClass);
        } else {
            $("#" + muteButtonId).removeClass(onClass);
            $("#" + muteButtonId).addClass(offClass);
        }
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the UI controller.
     */
    this.init = function () {
        audioEnabled = global.settings.getAudioEnabled();
        soundMuted = global.settings.getGlobalMute();
        if (audioEnabled) {
            that.show();
        }
        updateClass();
        registerListeners();
    };

    /**
     * Toggles the audio mute status.
     */
    this.toggleMute = function () {
        soundMuted = !soundMuted;
        updateSetting();
        updateAudio();
        updateClass();
    };

    /**
     * Shows the menu.
     */
    this.show = function () {
        $("#" + muteButtonId).show(400);
    };

    /**
     * Fades out the menu.
     */
    this.hide = function () {
        $("#" + muteButtonId).hide(400);
    };
}
