/**
 * This class contains functions specific to the Status tab.
 * Its init() function should be called immediately upon successful project load.
 * @param {GenericTab} generic An optional GenericTab to prevent having to create multiple copies.
 */
function StatusTab(generic) {
    // PRIVATE MEMBERS \\       var private = "test";
    var gen = generic ? generic : new GenericTab();
    var id = "statustab";
    var title = "Status";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * The onclick function for this tab.
     * Does nothing if the tab is already active.
     */
    function onClick() {
        if (gen.isActive(id)) {
            return;
        }
        gen.tabButtonTransition(id);
        global.sceneLoader.loadTabScene(id);
    }

    /**
     * Registers the onclick function for this tab.
     */
    function registerListeners() {
        $("#" + id).click(onClick);
    }

    /**
     * Builds and returns a HTML-subtitle.
     * @param {string} subtitle The actual subtitle.
     * @returns {string} The subtitle as a HTML-subtitle.
     */
    function buildSubtitle(subtitle) {
        return `<h2 class="subtitle">${subtitle}</h2>`;
    }

    /**
     * Builds and returns the healthbar of the Physical Health section of the status tab.
     * @returns {string} The healthbar of the Physical Health section of the status tab.
     */
    function buildPhysicalHealthBar() {
        var percentage = (global.kobold.status.physical.health / global.kobold.status.physical.max) * 100;
        var bar = `<div class="healthbar"><div class="healthbarinner health" style="width: ${percentage}%;"></div></div>`;
        return bar;
    }

    /**
     * Builds and returns the comment of the Physical Health section of the status tab.
     * @returns {string} The comment of the Physical Health section of the status tab.
     */
    function buildPhysicalHealthComment() {
        var percentage = (global.kobold.status.physical.health / global.kobold.status.physical.max) * 100;
        var comment;
        if (percentage <= 5) {
            comment = `<span class="warningtext">On the brink of death.</span>`;
        }
        if (5 < percentage && percentage <= 20) {
            comment = `<span class="warningtext">In need of medical attention.</span>`;
        }
        if (20 < percentage && percentage <= 50) {
            comment = `Seriously hurt.`;
        }
        if (50 < percentage && percentage <= 70) {
            comment = `In pain.`;
        }
        if (70 < percentage && percentage <= 90) {
            comment = `<span class="sneakytext">Cuts and bruises.</span>`;
        }
        if (90 < percentage) {
            comment = `<span class="sneakytext">Feeling fine.</span>`;
        }

        return `<div class="text healhbarcomment">${comment}</div>`;
    }

    /**
     * Builds and returns the sub-bar elements of the Physical Health section of the status tab.
     * @returns {string} The sub-bar elements of the Physical Health section of the status tab.
     */
    function buildPhysicalHealthSubBar() {
        var value = global.kobold.status.physical.health;
        var max = global.kobold.status.physical.max;
        var affected = global.kobold.status.physical.lasthit;
        var comment = buildPhysicalHealthComment();
        var numbers = `<div class="text healthbarnumber bold">${value} / ${max}</div>`;
        var lastHit = `<div class="text healhbarlasthit">Last affected by: ${affected}</div>`;
        return comment + numbers + lastHit;
    }

    /**
     * Builds and returns the Physical Health section of the status tab.
     * @returns {string} The Physical Health section of the status tab.
     */
    function buildPhysicalHealth() {
        return buildSubtitle("Health") + buildPhysicalHealthBar() + buildPhysicalHealthSubBar();
    }

    /**
     * Builds and returns the healthbar of the Mental Health section of the status tab.
     * @returns {string} The healthbar of the Mental Health section of the status tab.
     */
    function buildMentalHealthBar() {
        var percentage = (global.kobold.status.mental.health / global.kobold.status.mental.max) * 100;
        var bar = `<div class="healthbar"><div class="healthbarinner sanity" style="width: ${percentage}%;"></div></div>`;
        return bar;
    }

    /**
     * Builds and returns the comment of the Mental Health section of the status tab.
     * @returns {string} The comment of the Mental Health section of the status tab.
     */
    function buildMentalHealthComment() {
        var percentage = (global.kobold.status.mental.health / global.kobold.status.mental.max) * 100;
        var comment;
        if (percentage <= 5) {
            comment = `<span class="warningtext">Scarred for life.</span>`;
        }
        if (5 < percentage && percentage <= 20) {
            comment = `<span class="warningtext">Losing it.</span>`;
        }
        if (20 < percentage && percentage <= 50) {
            comment = `Distraught.`;
        }
        if (50 < percentage && percentage <= 70) {
            comment = `Confused.`;
        }
        if (70 < percentage && percentage <= 90) {
            comment = `<span class="sneakytext">Slightly irked.</span>`;
        }
        if (90 < percentage) {
            comment = `<span class="sneakytext">Clear of mind.</span>`;
        }

        return `<div class="text healhbarcomment">${comment}</div>`;
    }

    /**
     * Builds and returns the sub-bar elements of the Mental Health section of the status tab.
     * @returns {string} The sub-bar elements of the Mental Health section of the status tab.
     */
    function buildMentalHealthSubBar() {
        var value = global.kobold.status.mental.health;
        var max = global.kobold.status.mental.max;
        var affected = global.kobold.status.mental.lasthit;
        var comment = buildMentalHealthComment();
        var numbers = `<div class="text healthbarnumber bold">${value} / ${max}</div>`;
        var lastHit = `<div class="text healhbarlasthit">Last affected by: ${affected}</div>`;
        return comment + numbers + lastHit;
    }

    /**
     * Builds and returns the Mental Health section of the status tab.
     * @returns {string} The Mental Health section of the status tab.
     */
    function buildMentalHealth() {
        return buildSubtitle("Sanity") + buildMentalHealthBar() + buildMentalHealthSubBar();
    }

    /**
     * Builds and returns the healthbar of the Stamina section of the status tab.
     * @returns {string} The healthbar of the Stamina section of the status tab.
     */
    function buildStaminaBar() {
        var percentage = (global.kobold.status.stamina.health / global.kobold.status.stamina.max) * 100;
        var bar = `<div class="healthbar"><div class="healthbarinner stamina" style="width: ${percentage}%;"></div></div>`;
        return bar;
    }

    /**
     * Builds and returns the comment of the Stamina section of the status tab.
     * @returns {string} The comment of the Stamina section of the status tab.
     */
    function buildStaminaComment() {
        var percentage = (global.kobold.status.stamina.health / global.kobold.status.stamina.max) * 100;
        var comment;
        if (percentage <= 5) {
            comment = `<span class="warningtext">Ready to drop.</span>`;
        }
        if (5 < percentage && percentage <= 20) {
            comment = `<span class="warningtext">Exhausted.</span>`;
        }
        if (20 < percentage && percentage <= 50) {
            comment = `Out of breath.`;
        }
        if (50 < percentage && percentage <= 70) {
            comment = `Tired.`;
        }
        if (70 < percentage && percentage <= 90) {
            comment = `<span class="sneakytext">Active.</span>`;
        }
        if (90 < percentage) {
            comment = `<span class="sneakytext">Fresh.</span>`;
        }

        return `<div class="text healhbarcomment">${comment}</div>`;
    }

    /**
     * Builds and returns the sub-bar elements of the Stamina section of the status tab.
     * @returns {string} The sub-bar elements of the Stamina section of the status tab.
     */
    function buildStaminaSubBar() {
        var value = global.kobold.status.stamina.health;
        var max = global.kobold.status.stamina.max;
        var affected = global.kobold.status.stamina.lasthit;
        var comment = buildStaminaComment();
        var numbers = `<div class="text healthbarnumber bold">${value} / ${max}</div>`;
        var lastHit = `<div class="text healhbarlasthit">Last affected by: ${affected}</div>`;
        return comment + numbers + lastHit;
    }

    /**
     * Builds and returns the Stamina section of the status tab.
     * @returns {string} The Stamina section of the status tab.
     */
    function buildStamina() {
        return buildSubtitle("Stamina") + buildStaminaBar() + buildStaminaSubBar();
    }

    /**
     * Builds and returns the healthbar of the Sexual Exertion section of the status tab.
     * @returns {string} The healthbar of the Sexual Exertion section of the status tab.
     */
    function buildSexualExertionBar() {
        var percentage = (global.kobold.status.exertion.health / global.kobold.status.exertion.max) * 100;
        var bar = `<div class="healthbar"><div class="healthbarinner exertion" style="width: ${percentage}%;"></div></div>`;
        return bar;
    }

    /**
     * Builds and returns the comment of the Sexual Exertion section of the status tab.
     * @returns {string} The comment of the Sexual Exertion section of the status tab.
     */
    function buildSexualExertionComment() {
        var percentage = (global.kobold.status.exertion.health / global.kobold.status.exertion.max) * 100;
        var comment;

        if (percentage < 10) {
            comment = `<span class="sneakytext">Clean and tight.</span>`;
        }
        if (10 <= percentage && percentage < 30) {
            comment = `<span class="sneakytext">Gently fucked.</span>`;
        }
        if (30 <= percentage && percentage < 50) {
            comment = `Spent.`;
        }
        if (50 <= percentage && percentage < 80) {
            comment = `Used and abused.`;
        }
        if (80 <= percentage && percentage < 95) {
            comment = `<span class="warningtext">Thoroughly used fucktoy.</span>`;
        }
        if (95 <= percentage) {
            comment = `<span class="warningtext">Worn out cumdump.</span>`;
        }

        return `<div class="text healhbarcomment">${comment}</div>`;
    }

    /**
     * Builds and returns the sub-bar elements of the Sexual Exertion section of the status tab.
     * @returns {string} The sub-bar elements of the Sexual Exertion section of the status tab.
     */
    function buildSexualExertionSubBar() {
        var value = global.kobold.status.exertion.health;
        var max = global.kobold.status.exertion.max;
        var affected = global.kobold.status.exertion.lasthit;
        var comment = buildSexualExertionComment();
        var numbers = `<div class="text healthbarnumber bold">${value} / ${max}</div>`;
        var lastHit = `<div class="text healhbarlasthit">Last affected by: ${affected}</div>`;
        return comment + numbers + lastHit;
    }

    /**
     * Builds and returns the Sexual Exertion section of the status tab.
     * @returns {string} The Sexual Exertion section of the status tab.
     */
    function buildSexualExertion() {
        return buildSubtitle("Sexual exertion") + buildSexualExertionBar() + buildSexualExertionSubBar();
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = gen.buildTabHeader(title);
        tab += buildPhysicalHealth();
        tab += buildMentalHealth();
        tab += buildStamina();
        tab += buildSexualExertion();
        tab += gen.buildTabFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes this tab.
     * Registers the tab click listener.
     * Registers the tab with the scene loader.
     */
    this.init = function () {
        registerListeners();
        global.sceneLoader.registerScene(id, this);
    };

    /**
     * Loads this tab.
     */
    this.load = function () {
        gen.load();
        var tab = buildTab();
        global.ui.loadToMain(tab);
    };
}
