/**
 * Class capable of generating themes and adding those themes that have not yet been added to the game as CSS code.
 */
function ThemeGenerator() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Generates the theme as a CSS script and returns that script.
     * @param {string} name The name of the theme.
     * @param {Theme} theme The theme for which to generate a css script.
     * @returns {string} The generated css script.
     */
    this.generate = function (name, theme) {
        var output = `
            /**
             * COLOR SCHEME
             * Background:   ${theme.background.toHex()}    ${theme.background.toRgb()}
             * Main:         ${theme.main.toHex()}    ${theme.main.toRgb()}
             * Detail:       ${theme.detail.toHex()}    ${theme.detail.toRgb()}
             * Text:         ${theme.text.toHex()}    ${theme.text.toRgb()}
             * Rare:         ${theme.rare.toHex()}    ${theme.rare.toRgb()}
             * Danger:       ${theme.danger.toHex()}    ${theme.danger.toRgb()}
             * Sneaky:       ${theme.sneaky.toHex()}    ${theme.sneaky.toRgb()}
             * Blood:        ${theme.blood.toHex()}    ${theme.blood.toRgb()}
             * Sanity:       ${theme.sanity.toHex()}    ${theme.sanity.toRgb()}
             * Energy:       ${theme.energy.toHex()}    ${theme.energy.toRgb()}
             * Exertion:     ${theme.exertion.toHex()}    ${theme.exertion.toRgb()}
            **/

            .${name}, 
            .${name} .uibutton:active, 
            .${name} .saveslot, 
            .${name} .smallsaveslot, 
            .${name} .button:active,
            .${name} .button:disabled,
            .${name} .bigbutton,
            .${name} .textinput:disabled,
            .${name} .menuclosebutton,
            .${name} .menubutton,
            .${name} .loadingscreenwrapper{
                background-color: ${theme.background.toRgb()};  /* Background */
            }

            .${name} .popupcenter,
            .${name} .uibutton:hover,
            .${name} .button:hover,
            .${name} .tooltip,
            .${name} .healthbar,
            .${name} .textinput{
                border-color: ${theme.background.toRgb()};      /* Background */
            }

            .${name} .fullscreenpopup{
                background-color: ${theme.background.toRgba(0.7)};        /* Background */
            }

            .${name} .popupcenter,
            .${name} .popupcontrolbar,
            .${name} .tab,
            .${name} .uibutton,
            .${name} .main,
            .${name} .savecontrolbar,
            .${name} .tooltipheader,
            .${name} .tooltipbottom,
            .${name} .itemrowodd{
                background-color: ${theme.main.toRgb()};  /* Main */
            }

            .${name} .button,
            .${name} .button:disabled{
                border-color: ${theme.main.toRgb()};     /* Main */
            }

            .${name} .koboldadventure,
            .${name} .tabactive,
            .${name} .button,
            .${name} .smallseparator,
            .${name} .tooltip,
            .${name} .itemroweven,
            .${name} .textinput,
            .${name} .menubuttonselected{
                background-color: ${theme.detail.toRgb()};  /* Detail */
            }

            /* Separated to make things not-break on firefox. */
            .${name} .main::-webkit-scrollbar-thumb,
            .${name} .popupcenter::-webkit-scrollbar-thumb{ 
                background-color: ${theme.detail.toRgb()};  /* Detail */
            }

            .${name} .saveslot:hover, 
            .${name} .smallsaveslot:hover{
                border-color: ${theme.detail.toRgb()};    /* Detail */
            }

            .${name} a:link, 
            .${name} a:visited,
            .${name} .popupcontent,
            .${name} .koboldadventure,
            .${name} .tab,
            .${name} .tab:hover,
            .${name} .uibutton,
            .${name} .main,
            .${name} .savecomment,
            .${name} .button,
            .${name} .textinput,
            .${name} .textinput:disabled,
            .${name} .loadbar,
            .${name} .popupmenu{
                color: ${theme.text.toRgb()};               /* Text */
            }

            .${name} .tooltip{
                color: ${theme.text.toRgb()} !important;    /* Text */
            }

            .${name} .inlineseparator{
                background-color: ${theme.text.toRgb()};    /* Text */
            }

            .${name} .saveslotselected{
                border-color: ${theme.text.toRgb()} !important;     /* Text */
            }

            .${name} .selected{
                border-color: ${theme.rare.toRgb()} !important;      /* Rare */
            }

            .${name} .warning{
                background-color: ${theme.danger.toRgb()};  /* Danger */
            }

            .${name} .warningtext{
                color: ${theme.danger.toRgb()};    /* Danger */
            }

            .${name} .savelimit,
            .${name} .sneakytext{
                color: ${theme.sneaky.toRgb()};             /* Sneaky */
            }

            .${name} .health {
                background-color: ${theme.blood.toRgb()};      /* Blood */
            }

            .${name} .sanity {
                background-color: ${theme.sanity.toRgb()};      /* Sanity */
            }

            .${name} .stamina {
                background-color: ${theme.energy.toRgb()};      /* Energy */
            }

            .${name} .exertion {
                background-color: ${theme.exertion.toRgb()};      /* Exertion */
            }

            .${name} .dangeraura {
                box-shadow: 0px 0px 16px 6px ${theme.blood.toRgba(0.6)};      /* Blood */
            }`;
        
        if(theme.extraRules) {
            output += theme.extraRules;
        }
        return output;
    };
}
