/**
 * Arrival section of the Riverside Marsh.
 * @param {RiversideMarshController} controller The Riverside Marsh controller.
 */
function RiversideMarshArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new RiversideMarshDownstream(ctrl);
    var secondNext = new RiversideMarshUpstream(ctrl);

    var firstChoice = RiversideMarshArrivalChoice.DOWNSTREAM;
    var secondChoice = RiversideMarshArrivalChoice.UPSTREAM;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Traversing the deepwoods in near complete pitch-blackness isn't an easy task.
                            Luckily, your superb nightvision helps you more than a little, amplifying what little light manages to shine through the dense canopy.
                            Despite not being completely [i]blind[/i], you are in constant danger of tripping and falling.
                            Your feet are repeatedly getting caught on roots of varying shapes and sizes,
                            and when you finally find a place to plop down one of your scaly paws,
                            you still have barely visible low-hanging branches to worry about.
                            Flexible as you are, however, you succeed in making some form of progress.
                        [/p]
                        [p]
                            After nearly half an hour of slow and cautious trudging through the darkness, the ground beneath your feet begins to soften.
                            With every step, the soil [i]dampens[/i] further, and before long,
                            the previously solid dirt you were walking on is replaced by thick, sticky and slippery [b]mud[/b].
                            Coming to a halt for a moment, you become aware of a faint, continuous splashing in the distance.
                            Could you be nearing the river?
                        [/p]
                        [p]
                            Emboldened by the premise of a landmark you recognize, you press onwards.
                            After just a couple of minutes more of struggling to pass the terrain, the tightly packed trees give way to a clearing.
                            You were right!
                            It's the river!
                            You find yourself on top of the riverbank, gazing out onto the slowly streaming waterway, sparkling stars reflected by the water's surface.
                        [/p]
                        [p]
                            While you still have no idea where exactly you are, you know that Varanar is downstream from your home.
                            That, in turn, must mean that you are currently somewhere upstream.
                            Closer to the river's source than you've ever been.
                            If you follow the waterflow, it should lead you straight back to parts of the forest that you know.
                            Or you could head the opposite way, further away from civilization.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Downstream</button>`;

        var tooltip = global.parser.parse(`You need to get back home as soon as you can.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        disabled = "disabled";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Upstream</button>`;

        var tooltip = global.parser.parse(`Your adventure has barely even begun. Why turn back now? <span class="todo">Unavailable.</span>`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You go:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("forest_night");
        if (!subController.has()) {
            ctrl.riverAmbience.playSettingsDependent();
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.arrival.change();
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        //part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        //secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        //registerSecondListener();
    };
}

var RiversideMarshArrivalChoice = {
    DOWNSTREAM: 1,
    UPSTREAM: 2
};
