/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoSeki(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.SEKI;
    var reqController = ctrl.result;
    var changeController = ctrl.seki;

    var nextSceneReady = ctrl.sekiSceneReady;
    var nextSceneName = ctrl.sekiSceneName;
    var nextFolderName = ctrl.sekiFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.boughtBySeki = true;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            "[color=orange]One hundred.[/color]" a gentle, feminine voice rings out.
                            It's the half-naked vixen.
                            She's soon challenged by the goblin, whose stingy pockets seem far deeper than what you'd have imagined.
                            "[color=green]One hundred and twenty![/color]"
                            The kind-looking canine casts a wicked leer towards the small humanoid.
                            "[color=orange]One hundred and fifty. Or would you rather deal with a back-handed [b]greenskin[/b]?[/color]"
                            "[color=green][b]One fifty-one[/b]![/color]"
                        [/p]
                        [p]
                            Bartholomew seems conflicted.
                            For a moment, it feels as though a [b]fight[/b] is brewing between the two interested parties.
                            But then, right as temperatures are about to reach a boiling point, you cry out for your avian friend in the distance,
                            drawing attention from your captors and both the interested parties, effectively [b]defusing[/b] the situation.
                            The owl's head turns towards you.
                            His eyes go wide.
                            As fast as his old legs can carry him, he rushes over to the crowd.
                        [/p]
                        [p]
                            [color=brown][big][b]THREE HUNDRED![/b][/big][/color]
                        [/p]
                        [p]
                            Seki's voice [b]booms[/b] over the rest of the crowd, although he bursts into a coughing fit at the end of his shout.
                            "[color=gblue]Sold to the senile bird![/color]" Fenrir instantly jumps in.
                            The goblin and the vixen both grumble and complain, but the wolf's decision is final.
                            The crowd parts and money exchanges hands.
                        [/p]
                        [p]
                            While Barto attempts to chat with Seki, your avian protector seems more interested in getting you the hell out of there.
                            The elderly man held up for a few minutes out of sheer courtesy, Fenrir approaches you.
                            "[color=gblue]Well, ${name}, you're his now.
                            Next time we meet, you can thank me for not letting that [b]filthy[/b] goblin have you.
                            He'd have matched the old coot's offer if I hadn't stepped in, you know.
                            Either way, good luck out there.
                            You're going to need it.[/color]"
                        [/p]
                        [p]
                            Having said his farewells, the big wolf pushes you forwards, nudging you off of the small stage, towards your new [i]master[/i].
                            The deal concluded, the human and the lupine walk back to the carriages, bickering on how to split their profits.
                            Your old friend approaches you, leaning down to closely inspect your body.
                            "[color=brown]Thank goodness, you're not hurt. You [b]scared[/b] me, ${name}.[/color]"
                            Bringing a key to your neck, he takes off your slave collar, and angrily hurls it down the well.
                            "[color=brown]A money transport?
                            I thought I taught you better!
                            [b]Never[/b] go after high-profile targets![/color]"
                        [/p]
                        [p]
                            Noticing the prying eyes of a few lingering locals, Seki quite literally takes you under his wing.
                            [color=brown]Come now.
                            We'll talk more once we get inside.[/color]"
                            Those words said, the two of you walk towards his workshop, just a few steps away.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
