/**
 * The third part of the introduction of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestHome} home One of the parts the kobold can go next.
 * @param {ForestBridge} bridge One of the parts the kobold can go next.
 * @param {ForestWoods} woods One of the parts the kobold can go next.
 */
function ForestIntroductionPathSelection(controller, home, bridge, woods) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var bridgeId = "bridgeButton";
    var woodsId = "woodsButton";
    var homeId = "homeButton";
    
    var toHome = home;
    var toBridge = bridge;
    var toWoods = woods;

    var contentStart = `<div class="text">`;
    var rock = `You choose the ${global.kobold.inventory.createItemWithTooltip(new Rock())}.
                A hardy, dependable weapon your kind has been using since the dawn of ages.
                It might not be fancy and it may not be sharp, yet a good rock is all you need to bash someone's head in.
                Should the situation call for it, you could even throw it instead of trying to get up close and personal with someone twice your size.
                Which is mostly everyone, apart from other kobolds.`;
    var branch = `You choose the ${global.kobold.inventory.createItemWithTooltip(new Branch())}.
                  While a rather unorthodox weapon, this heavy stick can be used as a makeshift club.
                  You've heard of elves in a distant land fashioning sharp <span class="bold">swords</span> from wood like this.
                  If you had an entire workshop's worth of tools at hand, and a couple of days to fuck around with them, 
                  you're certain you could at the very least add something sharp and pointy to the hitting end.`;
    var neither = `You don't need a weapon to defend yourself.
                   The added weight would just slow you down.
                   Even if you'd picked either the rock or the branch, you wouldn't have been able to utilize either of them properly.
                   When you were little, you liked to fool around with the other young kobolds, smacking eachother with sticks and pretending you were brave, gallant knights.
                   Nowadays, you're old enough to realize that fighting of any kind is not, and never will be, your strong suit.
                   Unless some sort of miracle happens, that is.`;
    var rockOrBranchEnd = ` </div>
                            <div class="text">
                            You swing your new weapon around a bit, to get a feel for its weight. 
                            While you're certain you can cause some serious damage if you actually manage to strike someone with it, 
                            you heavily doubt your ability to land a hit in the heat of combat.`;
    var neitherEnd = `  </div>
                        <div class="text">
                            Still, that doesn't mean you're <span class="bold">completely</span> defenceless.
                            Your keen claws and razor-sharp teeth can rip through flesh as easily as they can shred clothing.
                            While you lack a weapon, the one thing you have plenty of is bravery.`;
    var contentEnd = `  </div>
                        <div class="text">
                            The issue of your personal safety resolved, you figure it's about time you found out <span class="bold">exactly</span> how much money you stole.
                            Your heart races as you lift the coin pouch's neck-strap over your head, and loosen the cord tying the top-end shut.
                            The moment the small bag opens, you are greeted with the warm glow of sunrays reflecting off the sparkling coins within, 
                            shining directly onto your face.
                        </div>
                        <div class="text">
                            You breathe an audible sigh of relief. 
                            The bag is filled to the brim with gold, alright.
                            Slightly awestruck, you waddle over to a nearby moss-covered rock.
                            Emptying the contents of the pouch atop the green-cushioned ancient,
                            you set about trying to count it all, one piece at a time.
                        </div>
                        <div class="text nomargin">
                            Two hundred and one...
                        </div>
                        <div class="text nomargin">
                            Two hundred and two...
                        </div>
                        <div class="text nomargin">
                            Two hundred and three!
                        </div>
                        <div class="text">
                            <span class="bold">You've managed to steal two hundred and three coins!</span>
                        </div>
                        <div class="text">
                            At first you get excited. 
                            <span class="bold">Really</span> excited.
                            You let out a rather cute, happy squeal.
                            Luckily enough, nobody was around to hear it.
                            For the first time in weeks, a content, genuinely happy smile forms at the end of your muzzle.
                            Then, the initial pleasant surprise fades, and more worries begin to flood your mind.
                            Two hundred and three coins is a lot of money, but it's still not enough to <span class="bold">completely</span> bail you out of debt.
                            But hey, at least it's more than nothing, right?
                        </div>
                        <div class="text">
                            You put the coins back into the pouch, which you secure around your neck.
                            Looking over your surroundings, you realize exactly where you are: 
                            at the edge of the forest, close to both Varanar as well as your own home.
                            It's time to decide where to go next.
                        </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds the rock part of the item selection.
     * @returns {string} The past part of the item selection.
     */
    function buildRock() {
        return rock + rockOrBranchEnd;
    }

    /**
     * Builds the branch part of the item selection.
     * @returns {string} The present part of the item selection.
     */
    function buildBranch() {
        return branch + rockOrBranchEnd;
    }

    /**
     * Builds the neither part of the item selection.
     * @returns {string} The future part of the item selection.
     */
    function buildNeither() {
        return neither + neitherEnd;
    }

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        var content = contentStart;
        var previousChoice = ctrl.intro.getItemChoice();
        if (previousChoice === ItemEnum.ROCK) {
            content += buildRock();
        }
        if (previousChoice === ItemEnum.BRANCH) {
            content += buildBranch();
        }
        if (previousChoice === 0) {
            content += buildNeither();
        }
        content += contentEnd;
        return content;
    }

    /**
     * Builds and returns the Varanar choice button.
     * @returns {string} The Varanar choice button.
     */
    function buildVaranarChoice() {
        var disabled = ctrl.intro.hasMadePathChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getPathChoice() === ForestIntroductionPathChoiceEnum.BRIDGE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${bridgeId}" ${disabled}>Varanar</button>`;

        var popupMessage = `You know a small, hidden path that leads towards the capital. You should go pay off your debt immediately.`;
        var popupContainer = global.ui.makeToolTip(button, popupMessage, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the woods choice button.
     * @returns {string} The woods choice button.
     */
    function buildWoodsChoice() {
        var disabled = ctrl.intro.hasMadePathChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getPathChoice() === ForestIntroductionPathChoiceEnum.WOODS;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${woodsId}" ${disabled}>The woods</button>`;

        var popupMessage = `Those soldiers could still be on your tail. You should hide from them somewhere in the woods.`;
        var popupContainer = global.ui.makeToolTip(button, popupMessage, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the home choice button.
     * @returns {string} The home choice button.
     */
    function buildHomeChoice() {
        var disabled = ctrl.intro.hasMadePathChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getPathChoice() === ForestIntroductionPathChoiceEnum.HOME;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${homeId}" ${disabled}>Home</button>`;

        var popupMessage = "You've had a long, emotion-filled day. It's time to go home. If a debt collector comes by, you can pay him all you have.";
        var popupContainer = global.ui.makeToolTip(button, popupMessage, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You set off towards:</div>`;
        choice += buildVaranarChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildWoodsChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildHomeChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + homeId), $("#" + bridgeId), $("#" + woodsId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next part.
     * @param {ForestHomePathChoiceEnum} next Which part to load.
     */
    function loadNextPart(next) {
        var part;
        if(next === ForestIntroductionPathChoiceEnum.HOME) {
            part = toHome;
        }
        if(next === ForestIntroductionPathChoiceEnum.BRIDGE) {
            part = toBridge;
        }
        if(next === ForestIntroductionPathChoiceEnum.WOODS) {
            part = toWoods;
        }
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }
    
    /*
     * Registers a listener for the woods button.
     */
    function registerWoodsListener() {
        $("#" + woodsId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makePathChoice(ForestIntroductionPathChoiceEnum.WOODS);
            loadNextPart(ForestIntroductionPathChoiceEnum.WOODS);
        });
    }
    
    /*
     * Registers a listener for the home button.
     */
    function registerHomeListener() {
        $("#" + homeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makePathChoice(ForestIntroductionPathChoiceEnum.HOME);
            loadNextPart(ForestIntroductionPathChoiceEnum.HOME);
        });
    }
    
    /*
     * Registers a listener for the bridge button.
     */
    function registerBridgeListener() {
        $("#" + bridgeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makePathChoice(ForestIntroductionPathChoiceEnum.BRIDGE);
            loadNextPart(ForestIntroductionPathChoiceEnum.BRIDGE);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "introductionPath";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.intro.hasMadeItemChoice()) {
            return "";
        }
        var statChange = ctrl.intro.pathSelectionStatusChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += statChange;
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.intro.hasMadeItemChoice()) {
            return;
        }
        if (ctrl.intro.hasMadePathChoice()) {
            return;
        }
        registerWoodsListener();
        registerHomeListener();
        registerBridgeListener();
    };
}

/**
 * Path choices to be made.
 */
var ForestIntroductionPathChoiceEnum = {
    HOME: 1,
    BRIDGE: 2,
    WOODS: 3
};
