/**
 * The first part of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestIntroductionItemSelection} nextPart The next part to load once finished.
 */
function ForestIntroductionRecovering(controller, nextPart) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var next = nextPart;

    var pastId = "introPast";
    var presentId = "introPresent";
    var futureId = "introFuture";

    var contentStart = `<div class="subtitle">
                            Introduction
                        </div>
                        <div class="text">
                            You ran. 
                            You ran as fast as you could, for as long as you could.
                            You ran until your lungs began to burn, and your legs felt like they were about to explode.
                            You sprinted through the woods, ill-gotten gains in hand.
                            You don't think anyone saw you.
                            Oh god, you <span class="bold">hope</span> nobody saw you.
                        </div>
                        <div class="text">
                            Coming to a rest against a nearby tree, you pant, huff and wheeze loudly, practically gasping for air.
                            With one hand you clutch your `;

    var contentMid = ` With the other, you grope the hefty coin pouch hanging around your neck, 
                            the myriad of shiny gold pieces within clattering against one another in a soul-mending harmony.
                            Yet your body aches just as much as your spirit is recovering.
                        </div>
                        <div class="text">
                            You finally regain enough breath to <span class="bold">think</span>.
                            Your heart is racing, pounding so hard it makes your entire body shiver.
                            You can barely keep your hands from shaking.
                            A last tidbit of adrenaline courses through your system.
                            You look to the left. You look to the right. Nobody.
                            You did it. 
                            You actually pulled it off. 
                            You managed to steal from one of the king's highly secure money transports.
                        </div>
                        <hr class="smallseparator">
                        <div class="text">
                            In your desperation to meet your deadline, to stave off your impending doom,
                            the rewards seemed to far outweigh the risk.
                            The small convoy of gold-filled-coffer-carrying riding horses was momentarily
                            abandoned by the footmen guarding it, the mixture of anthros and humans rushing off 
                            to test their mettle against a big, brown forest bear.
                            With only the caravan master, perched atop the largest carriage at the very front of the 
                            transport left, you decided to make your move.
                        </div>
                        <div class="text">
                            You began at the very rear end of the convoy, a myriad of beasts of burden between you and the overseer.
                            At first, you went for the coffers, small chests filled to the brim with coin. 
                            They were locked, and far too heavy for you to carry.
                            To your despair, nearly everything of value was tucked away in those crates, where greedy hands like yours couldn't reach.
                            Moving forward along the length of the transport, you tested chest after chest, hoping they might have forgotten to lock at least <span class="bold">one</span> of them.
                            No success.
                        </div>
                        <div class="text">
                            You were about to give up hope once more, 
                            to give in to your fears and run away with nothing but your undoubtedly short-lived life to show for your daring venture.
                            Then, out of the corner of your eye, you witnessed your salvation.
                            While the rest of the caravan was indeed too secure for you to tinker with, 
                            several small bags of gold were tied to the side of the foreman's carriage, 
                            kept safe only by the watchful eye of the burly human himself.
                        </div>
                        <div class="text">
                            You snuck in between the legs of the <span class="sneakytext bold">visibly aroused</span> riding horse directly behind the overseer's wagon.
                            You inched closer and closer, crawling flat on your belly through the slightly-trampled dirt and mud that lined the small road.
                            Just as you were steeling yourself, bracing your mind for actually <span class="bold">going through</span> with this, distant voices
                            rang out from the rear of the convoy.
                            The footmen had returned.
                        </div>
                        <div class="text">
                            Panic surged through your mind.
                            If you'd attempted to stay hidden, they would have found you.
                            And even if they wouldn't have, the caravan would surely have trampled you.
                            A primal <span class="italic">fight or flight</span> reaction triggering in your brain, you hopped to your feet.
                            It felt as though your body was acting out of its own, against your better judgement.
                            In a spur of the moment, you reached for the carriage, yanking a single money-laden bag off the side.
                            With the pouch in hand, you bolted off the path, into the heart of the forest.
                            And the rest is history.
                        </div>
                        <hr class="smallseparator">
                        <div class="text">
                            As adrenaline slowly starts to fade from your body, you begin to feel incredibly lightheaded. 
                            You drop to your knees, your heavily overexerted legs far too weary to carry your meagre frame.
                            Your tongue lolls out of your mouth obscenely.
                            Your entire body feels like it's on fire.
                            You squeeze the coin pouch once more.
                            You still can't believe it's there.
                        </div>
                        <div class="text">
                            You pushed yourself <span class="bold">too</span> hard.
                            You feel like you're about to pass out.
                            You tilt your head downwards, staring blankly at the root of the tree in front of you.
                            You can't even <span class="bold">see</span> clearly anymore.
                            Blackness seeps into the corners of your eyes.
                            The rest of your vision is blurry.
                            You can't afford to pass out now.
                            You need something to think of, something to focus on, something to keep you from <span class="bold">falling apart</span>.
                        </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        var content = contentStart;
        content += ctrl.intro.recoveringChestCovered() ? "sweaty chest rag." : "bare chest.";
        content += contentMid;
        return content;
    }

    /**
     * Builds and returns the past choice button.
     */
    function buildPastChoice() {
        var disabled = ctrl.intro.hasMadeThinkingChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getThinkingChoice() == ForestIntroductionThinkingChoiceEnum.PAST;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${pastId}" ${disabled}>The past</button>`;
        return button;
    }

    /**
     * Builds and returns the present choice button.
     */
    function buildPresentChoice() {
        var disabled = ctrl.intro.hasMadeThinkingChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getThinkingChoice() == ForestIntroductionThinkingChoiceEnum.PRESENT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${presentId}" ${disabled}>The present</button>`;
        return button;
    }

    /**
     * Builds and returns the future choice button.
     */
    function buildFutureChoice() {
        var disabled = ctrl.intro.hasMadeThinkingChoice() ? "disabled" : "";
        var isSelected = ctrl.intro.getThinkingChoice() == ForestIntroductionThinkingChoiceEnum.FUTURE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${futureId}" ${disabled}>The future</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You think of:</div>`;
        choice += buildPastChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildPresentChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFutureChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Loads and displays the next part.
     */
    function loadNextPart() {
        var part = next.build(true);
        global.ui.appendBeforeFinisher(part, global.ui.genericHeaderId);
        $("#" + next.id).fadeIn(400);
        next.registerListeners();
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + pastId), $("#" + presentId), $("#" + futureId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Registers a listener to the past button.
     */
    function registerPastListener() {
        $("#" + pastId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makeThinkingChoice(ForestIntroductionThinkingChoiceEnum.PAST);
            loadNextPart();
        });
    }

    /**
     * Registers a listener to the present button.
     */
    function registerPresentListener() {
        $("#" + presentId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makeThinkingChoice(ForestIntroductionThinkingChoiceEnum.PRESENT);
            loadNextPart();
        });
    }

    /**
     * Registers a listener to the future button.
     */
    function registerFutureListener() {
        $("#" + futureId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.intro.makeThinkingChoice(ForestIntroductionThinkingChoiceEnum.FUTURE);
            loadNextPart();
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "introductionRecovering";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.woods.getArrivalChoice() !== ForestWoodsArrivalChoiceEnum.UNKNOWN && !ctrl.bandit.hasSource()) {
            ctrl.bgm.loop();
        }
        var loss = ctrl.intro.recoveringStatusChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += loss;
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.intro.hasMadeThinkingChoice()) {
            return;
        }
        registerPastListener();
        registerPresentListener();
        registerFutureListener();
    };
}

/**
 * Thinking choices to be made.
 */
var ForestIntroductionThinkingChoiceEnum = {
    PAST: 1,
    PRESENT: 2,
    FUTURE: 3
};
