/**
 * Controller for the Forest River scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestRiverController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "VaranarRiver";
    this.nextFolderName = "ForestToVaranar";

    this.homeSceneReady = true;
    this.homeSceneName = "Home";
    this.homeFolderName = "";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");

    this.swim = new ChoiceController(id, "swim");
    this.swimming = new ChangeController(id, "swimming", function () {
        global.kobold.status.physical.increase(5, "Freezing water");
        global.kobold.status.physical.decrease(2, "Cold");
        global.kobold.status.mental.decrease(6, "Impending rape");
        global.kobold.status.stamina.decrease(6, "Swimming");
        if (that.swim.get() === ForestRiverSwimChoice.STRIP) {
            global.kobold.inventory.equipment.strip(SlotEnum.BRA);
            global.kobold.inventory.equipment.strip(SlotEnum.UNDERWEAR);
            global.kobold.inventory.equipment.strip(SlotEnum.PANTS);
        }
    }, function () {
        var notes = [
            new Change("Freezing water", "Health", +5),
            new Change("Cold", "Health", -2),
            new Change("Bandits", "Sanity", -3),
            new Change("Impending rape", "Sanity", -3),
            new Change("Swimming", "Stamina", -6)
        ];

        if (that.swim.get() === ForestRiverSwimChoice.STRIP) {
            var bra = that.misc.bra();
            if (bra) {
                notes.push(new Change("Stripped bra", global.kobold.inventory.createItemWithTooltip(bra, true), -1));
            }
            var underwear = that.misc.underwear();
            if (underwear) {
                notes.push(new Change("Stripped underwear", global.kobold.inventory.createItemWithTooltip(underwear, true), -1));
            }
            var pants = that.misc.pants();
            if (pants) {
                notes.push(new Change("Stripped pants", global.kobold.inventory.createItemWithTooltip(pants, true), -1));
            }
        }

        return global.ui.change.buildNotification(notes);
    });

    this.keepGoing = new ChoiceController(id, "keepGoing");
    this.otherSide = new ChangeController(id, "otherSide", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(8, "Surrounded by bandits");
        global.kobold.status.stamina.decrease(8, "Fast swimming");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Kicked", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Near-misses", "Sanity", -4),
            new Change("Surrounded", "Sanity", -4),
            new Change("Fast swimming", "Stamina", -8)
        ]);
    });
    this.upstreamSuccess = new ChangeController(id, "upstreamSuccess", function () {
        global.kobold.status.physical.decrease(6, "Drowning");
        global.kobold.status.mental.increase(4, "Back on dry land");
        global.kobold.status.stamina.decrease(6, "Made it ashore");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Drowning", "Health", -4),
            new Change("Successful escape", "Sanity", +6),
            new Change("Almost drowned", "Sanity", -4),
            new Change("Back on dry land", "Sanity", +2),
            new Change("Underwater swimming", "Stamina", -4),
            new Change("Drowning", "Stamina", -4),
            new Change("Made it ashore", "Stamina", +2)
        ]);
    });
    this.upstreamFail = new ChangeController(id, "upstreamFail", function () {
        global.kobold.status.physical.decrease(21, "Knocked out");
        global.kobold.status.mental.decrease(8, "Almost drowned");
        global.kobold.status.stamina.decrease(8, "Drowning");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Drowning", "Health", -4),
            new Change("Hit by rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Failed to escape", "Sanity", -4),
            new Change("Almost drowned", "Sanity", -4),
            new Change("Underwater swimming", "Stamina", -4),
            new Change("Drowning", "Stamina", -4)
        ]);
    });
    this.downstreamSuccess = new ChangeController(id, "downstreamSuccess", function () {
        global.kobold.status.physical.decrease(2, "Freezing cold");
        global.kobold.status.mental.increase(4, "Back on dry land");
        global.kobold.status.stamina.decrease(6, "Made it ashore");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Successful escape", "Sanity", +6),
            new Change("Heart-racing dodging", "Sanity", -4),
            new Change("Back on dry land", "Sanity", +2),
            new Change("Current-assisted swimming", "Stamina", -4),
            new Change("Dodging rocks", "Stamina", -4),
            new Change("Made it ashore", "Stamina", +2)
        ]);
    });
    this.downstreamFail = new ChangeController(id, "downstreamFail", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(1, "Dodging rocks");
        global.kobold.status.stamina.decrease(8, "Dodging rocks");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Hit rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Escaped", "Sanity", +3),
            new Change("Heart-racing dodging", "Sanity", -4),
            new Change("Current-assisted swimming", "Stamina", -4),
            new Change("Dodging rocks", "Stamina", -4)
        ]);
    });

    this.freeze = new ChoiceController(id, "freeze");

    this.weapon = new ChoiceController(id, "weapon");
    this.strike = new ChangeController(id, "strike", function () {
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(4, "Blinded by pride");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Hit by rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Triumph", "Sanity", +3),
            new Change("Pride", "Sanity", +3),
            new Change("Blinded by pride", "Sanity", -10)
        ]);
    });
    this.reconsider = new ChangeController(id, "reconsider", function () {
        global.kobold.inventory.coins = global.kobold.inventory.coins - that.misc.gold();
        global.kobold.status.physical.decrease(17, "Knocked out");
        global.kobold.status.mental.decrease(17, "Blinded by pride");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cold", "Health", -2),
            new Change("Punched in the face", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Treated like a child", "Sanity", -4),
            new Change("Blinded by rage", "Sanity", -10),
            new Change("Fucked up bigtime", "Sanity", -3),
            new Change("Gold taken", "Gold", -that.misc.gold())
        ]);
    });

    this.handsUp = new ChoiceController(id, "handsUp");

    this.spread = new ChangeController(id, "spread", function () {
        global.kobold.status.physical.decrease(2, "Stretched");
        global.kobold.status.mental.increase(3, "Fingered by Goliath");
        global.kobold.status.exertion.increase(7, "Thorough fingering");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stretched", "Health", -2),
            new Change("Doubt", "Sanity", -1),
            new Change("Delusion", "Sanity", -1),
            new Change("Pleasurable fingering", "Sanity", +3),
            new Change("Internal massage", "Sanity", +3),
            new Change("Anxiousness", "Sanity", -1),
            new Change("Thoroughly fingered", "Sexual exhaustion", +7, true)
        ]);
    });

    this.struggle = new ChangeController(id, "struggle", function () {
        global.kobold.status.physical.decrease(2, "Stretched");
        global.kobold.status.mental.decrease(7, "Fingered by Goliath");
        global.kobold.status.exertion.increase(7, "Thorough fingering");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stretched", "Health", -2),
            new Change("Unwillingness", "Sanity", -4),
            new Change("Impending rape", "Sanity", -3),
            new Change("Thoroughly fingered", "Sexual exhaustion", +7, true)
        ]);
    });

    this.kick = new ChangeController(id, "kick", function () {
        global.kobold.inventory.coins = global.kobold.inventory.coins - that.misc.gold();
        global.kobold.status.physical.decrease(15, "Knocked out");
        global.kobold.status.mental.decrease(7, "Knocked out by Goliath");
        global.kobold.status.stamina.decrease(3, "Kicking Goliath's face");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Punched in the face", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Temporary victory", "Sanity", +5),
            new Change("Crushing defeat", "Sanity", -12),
            new Change("Spectacular maneuver", "Stamina", -3),
            new Change("Gold taken", "Gold", -that.misc.gold())
        ]);
    });

    this.preMouthHappen = new ContinueController(id, "preMouthHappen");

    this.suck = new ChangeController(id, "suck", function () {
        global.kobold.body.oralVirgin = false;
    }, function () {
        return "";
    });

    this.mouthHappen = new ChangeController(id, "mouthHappen", function () {
        global.kobold.body.oralVirgin = false;
    }, function () {
        return "";
    });

    this.bite = new ChangeController(id, "bite", function () {
        global.kobold.status.physical.decrease(15, "Knocked out");
        global.kobold.status.mental.decrease(2, "Biting Goliath's dick");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hit by rock", "Health", -10),
            new Change("Knocked out", "Health", -5),
            new Change("Taste of flesh", "Sanity", -4),
            new Change("Bested the giant", "Sanity", +10),
            new Change("Plan went wrong", "Sanity", -8)
        ]);
    });

    this.mouthFinish = new ChangeController(id, "mouthFinish", function () {
        global.kobold.status.physical.decrease(6, "Vomiting cum");
        global.kobold.status.mental.decrease(7, "Abandoned by Goliath");
        global.kobold.status.stamina.decrease(4, "Almost drowned");
        global.kobold.status.exertion.increase(15, "Deepthroating cock");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Cum-dinner", "Health", -1),
            new Change("Almost drowning", "Health", -3),
            new Change("Vomiting cum", "Health", -2),
            new Change("Belly full of semen", "Sanity", +5),
            new Change("Almost drowned", "Sanity", -2),
            new Change("Vomiting cum", "Sanity", -2),
            new Change("All alone", "Sanity", -8),
            new Change("Almost drowned", "Stamina", -4),
            new Change("Deepthroated cock", "Sexual exhaustion", +10, true),
            new Change("Swallowed cum", "Sexual exhaustion", +5, true)
        ]);
    });

    this.mouthDoNot = new ChoiceController(id, "mouthDoNot");

    this.preSexHappen = new ContinueController(id, "preSexHappen");

    this.sexHappen = new ChangeController(id, "sexHappen", function () {
        if(that.misc.dick()) {
            global.kobold.body.analVirgin = false;
        } else {
            global.kobold.body.vaginalVirgin = false;
        }
        global.kobold.status.physical.decrease(10, "Drowning");
        global.kobold.status.mental.decrease(15, "Drowning");
        global.kobold.status.stamina.decrease(13, "Drowning");
        global.kobold.status.exertion.increase(25, "Oversized fuck");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Oversized insertion", "Health", -4),
            new Change("Lack of air", "Health", -3),
            new Change("Passing out", "Health", -3),
            new Change("Facefucked", "Sanity", -5),
            new Change("Almost drowned", "Sanity", -2),
            new Change("Raped", "Sanity", -5),
            new Change("Drowned", "Sanity", -10),
            new Change("Escaped the pain", "Sanity", +7),
            new Change("Lack of air", "Stamina", -3),
            new Change("Drowned", "Stamina", -10),
            new Change("Facefucked", "Sexual exhaustion", +10, true),
            new Change("Oversized sex", "Sexual exhaustion", +10, true),
            new Change("Came inside", "Sexual exhaustion", +5, true)
        ]);
    });

    this.sexPlay = new ChangeController(id, "sexPlay", function () {
        if(that.misc.dick()) {
            global.kobold.body.analVirgin = false;
        } else {
            global.kobold.body.vaginalVirgin = false;
        }
        global.kobold.status.physical.decrease(10, "Drowning");
        global.kobold.status.mental.increase(3, "Drowning");
        global.kobold.status.stamina.decrease(13, "Drowning");
        global.kobold.status.exertion.increase(30, "Oversized fuck");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Oversized insertion", "Health", -4),
            new Change("Lack of air", "Health", -3),
            new Change("Passing out", "Health", -3),
            new Change("Deepthroated dick", "Sanity", +5),
            new Change("Almost drowned", "Sanity", -2),
            new Change("Total ecstacy", "Sanity", +5),
            new Change("Climax", "Sanity", +5),
            new Change("Drowned", "Sanity", -10),
            new Change("Lack of air", "Stamina", -3),
            new Change("Drowned", "Stamina", -10),
            new Change("Deepthroated cock", "Sexual exhaustion", +10, true),
            new Change("Oversized fuck", "Sexual exhaustion", +10, true),
            new Change("Reached climax", "Sexual exhaustion", +5, true),
            new Change("Came inside", "Sexual exhaustion", +5, true)
        ]);
    });

    /**this.secondChoice = {
     DECLINE: 1,
     ACCEPT: 2
     };*/

    this.fragments = {};
    this.fragments.mouthHappen = new ForestRiverMouthHappen(this);
    this.fragments.swimming = new ForestRiverSwimming(this);

    this.bgm = new AudioController(id, "res/audio/effects/river.mp3", 100);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}
