/**
 * Arrival section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverSwim(ctrl);
    var secondNext = new ForestRiverBridge(ctrl);

    var firstChoice = ForestRiverArrivalChoice.SWIM;
    var secondChoice = ForestRiverArrivalChoice.BRIDGE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After a solid half-hour of high-paced marching through the forest,
                            you arrive at the forgotten river crossing.
                            The trek took quite a bit longer than you thought it would.
                            The sun's already starting its descent.
                            You don't think it'll be light out for much longer.
                            While you'd love to rest your weary feet for a bit, you simply don't have the time.
                            You step out onto the riverbank, and inspect the tiny bridge while you still can.
                        [/p]
                        [p]
                            The old, wooden construct is [b]far[/b] more dilapidated than it was the last time you were here.
                            It's only [b]barely[/b] still standing, several of the rotting logs supporting it having visible cracks in them,
                            one of the load-bearing poles broken completely.
                            As a small gust of wind picks up, the bridge sways back and forth ominously, like it's about to [b]break[/b] there and then.
                            But, despite looking like it's long-overdue a one-way trip into the river, it holds.
                        [/p]
                        [p]
                            The decrepit state of the bridge has you second-guessing your plans.
                            You'd hoped to find it in a bit better condition, but it seems time has taken its toll on the unmaintained structure.
                            A shame, you have some fond memories escaping from pitchfork-wielding mobs across it.
                            Those farmers never did find out how it was that you kept escaping their clutches.
                        [/p]
                        [p]
                            Humans, a bunch of [i]idiots[/i], the lot of them.
                            They may be [b]bigger[/b] and [b]stronger[/b] and [b]smarter[/b] than you are,
                            but you haven't met a single one able to match your thieving wit!
                            Then again, you doubt the poor dirt farmers that inhabit the hamlet outside of the city are as clever as the rest of their kind.
                            You're certain that the people of Varanar will be a lot quicker to see through your hare-brained schemes.
                        [/p]
                        [p]
                            Snapping out of your reminiscing, you focus on the task at hand.
                            The easy river-crossing you were counting on is [b]not[/b] a part of the hand you were dealt.
                            You [i]could[/i] still risk going across bridge, but that would be [b]very[/b] unsafe, to say the least.
                            You can already picture yourself falling through the flimsy wood.
                            Or maybe the entire thing'll give way, sending you crashing down into the rocky river.
                            If you're lucky, you'll live to tell the tale.
                            If not, you could break your neck, drown underneath debris, or crack your skull by hitting your head against a rock on the way down.
                            And you're not very keen on becoming a gold-laden skeletal corpse for a lucky adventurer to stumble upon.
                        [/p]
                        [p]
                            But you don't want a single, small setback like this to be the end of your expedited journey to the capital.
                            You [b]aren't[/b] going home without at least [b]trying[/b] to cross.
                            The bridge is risky, but there are [b]alternatives[/b].
                            Alternatives like [b]swimming[/b] to the other side.
                            The current is manageable in this area.
                            The water's probably freezing cold,
                            and the river's pretty wide,
                            but you think you [i]should[/i] be able to manage to swim across without too much trouble.
                            It's either that, or brave the bridge.
                            Time to pick your poison.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Swim</button>`;

        var tooltip = global.parser.parse(`Swim across the river. It's not [i]that[/i] wide.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} disabled>Bridge</button>`;

        var tooltip = global.parser.parse(`Cross the bridge. [todo]Unavailable.[/todo]`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.applyTheme("forest");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        //part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        //secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        //registerSecondListener();
    };
}

var ForestRiverArrivalChoice = {
    SWIM: 1,
    BRIDGE: 2
};
