/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverFreeze(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverSwimmingChoice.FREEZE;
    var reqController = ctrl.swimming;
    var subController = ctrl.freeze;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new ForestRiverHands(ctrl);
    var secondNext = new ForestRiverWeapon(ctrl);

    var firstChoice = ForestRiverFreezeChoice.HANDS;
    var secondChoice = ForestRiverFreezeChoice.WEAPON;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The guy with the slingshot looks like he has a pair of good eyes on him,
                            and the slinger, too, seems pretty experienced in the use of his weapon.
                            You don't [b]dare[/b] to move, lest they [b]pelt[/b] you with rocks.
                            Worse yet, if you run away, and the big dude gets his hands on you, he'd tear you limb from limb!
                            No, trying to swim away would not be the best thing to do right now.
                            There may be a way out of this yet, but you need to be [b]smart[/b] about it.
                        [/p]
                        [p]
                            You tread water in-place, keeping your head above the surface without moving.
                            Turning around, you witness the leader of the gang upping his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            You cast a pleading gaze up at the encroaching monster of a human, hoping to be granted some form of mercy.
                            But instead of pity, there is only [b]lust[/b] and [b]disdain[/b] in his eyes.
                            "[color=green]Hands up, lizard.[/color]"
                            he commands, eagerly licking his lips.
                            "[color=green]I don't want there to be any [b]surprises[/b].
                            And neither do [b]you[/b], if you want to leave this river alive.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Hands up</button>`;

        var tooltip = global.parser.parse(`If you comply with his demands, he'll have no reason to hurt you. Right?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var weapon = ctrl.misc.weapon();
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 250px;">Reach for ${weapon ? `your weapon` : `a rock`}</button>`;

        var tooltip = global.parser.parse(`Like hell you're going to surrender to some human ruffian. If he wants a piece of you, let'em come get some.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 250px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestRiverFreezeChoice = {
    HANDS: 1,
    WEAPON: 2
};
