/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverReconsider(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverWeaponChoice.RECONSIDER;
    var reqController = ctrl.weapon;
    var changeController = ctrl.reconsider;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        global.kobold.history.shared.forestToVaranar.riverMoneyTaken = true;
        var weapon = ctrl.misc.weapon();
        var weaponTT = global.kobold.inventory.createItemWithTooltip(weapon);
        var rockTT = global.kobold.inventory.createItemWithTooltip(new Rock());
        var toReturn = `[p]
                            The man comes to a halt directly in front of you.
                            Now would be your chance to strike, but instead, you [b]completely[/b] freeze up.
                            You swallow in fear, the bandit simply [b]too[/b] imposing for you to act.
                            How the hell does [b]anyone[/b] grow to be that [b]huge[/b]?!
                            Was his father a [b]giant[/b] or something?!
                        [/p]
                        [p]
                            With a lecherous look on his face, the human eyes you up and down.
                            Suddenly, his visage turns to [b]anger[/b].
                            He reaches underwater, and [b]grabs[/b] your ${weapon ? weaponTT : rockTT}-clutching hand by the wrist,
                            squeezing down hard enough to make you drop your weapon!
                            "[color=green]Trying to [b]ambush[/b] me, were you?[/color]"
                            he speaks, leaning down slightly, staring straight into your eyes.
                        [/p]
                        [p]
                            You [b]swear[/b] that you weren't planning to hurt him!
                            Okay, maybe the thought crossed your mind, but you weren't going to go through with it!
                            Honestly!
                            The human completely disregards your excuses.
                            "[color=green]I [i]was[/i] just going to fuck you, but now, I think I'll be taking [b]this[/b].[/color]"
                            With his free hand, he [b]grabs[/b] your coinpouch, and effortlessly [b]tears[/b] it from your neck.
                        [/p]
                        [p]
                            No!
                            You need that!
                            He can't have it!
                            You reach for the purse, but the man teasingly pulls it backwards, treating you like a [b]child[/b].
                            Unable to control yourself, you [b]lash[/b] out in pure rage, [b]scratching[/b] his face with your sharp claws.
                            Snapping back to your senses, a wave of fright washes over you as you realize what you did.
                            The human angrily glares at you, a tiny bit of blood seeping from his cheek.
                        [/p]
                        [p]
                            Oh no!
                            Oh no, no, no!
                            Y-you didn't mean to do that!
                            You got so angry, you lost control for a bit!
                            He can have the coins!
                            As an apology, okay?
                            Y-you're cool, right?
                            Two words are all that leave the bandit's mouth.
                            "[color=green]Good night.[/color]"
                            And with that, be [b]bashes[/b] your forehead with his fist,
                            using every overdeveloped muscle in his inflated arm to [b]knock you out[/b] in a single blow.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
