/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverStrike(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverWeaponChoice.STRIKE;
    var reqController = ctrl.weapon;
    var changeController = ctrl.strike;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        global.kobold.history.shared.forestToVaranar.riverGoliathKilled = true;
        var toReturn = `[p]
                            The man comes to a halt directly in front of you.
                            Now's your chance.
                            Gathering all of your courage and gritting your teeth,
                            you raise your weapon up out of the water, brandishing it up high above.
                            The dim-witted brute dumbfoundedly stares at it,
                            then, before he can react, you [b]plummet[/b] your blunt armament down atop his head,
                            [b]bashing[/b] the muscular man's cranium, caving his skull in.
                        [/p]
                        [p]
                            A loud, satisfying and slightly [i]sickening[/i] [b]crack[/b] raises your hopes high.
                            The human blankly stares at you.
                            His mouth falls agape, as though he's trying to speak, but no words leave his lips.
                            A trickle of blood oozes from his right nostril.
                            His eyes cross, before rolling into the back of his head.
                            Then, finally, after a few tense seconds, the human falls backwards into the water,
                            which freely floods into his open maw.
                            Sinking deeper and deeper,
                            a few final bubbles of air escaping from his lungs is the last you ever see of the big and burly thug.
                        [/p]
                        [p]
                            Pride swells your chest, felling a human that big being no easy feat for a small kobold like yourself.
                            The two men accompanying the beastly human don't know how to react.
                            They look at eachother in disbelief.
                            While their leader sinks to the riverbed,
                            they slowly come to their senses.
                        [/p]
                        [p]
                            [big]
                                "[color=cyan][b]Goliath[/b]! I'll get you for that, you [b]stupid kobold[/b]![/color]"
                            [/big]
                        [/p]
                        [p]
                            The slingshot-wielder aims his weapon, and fires a precise shot your way.
                            Not precise enough, however.
                            The sharp rock flies right by your cheek, missing you by less than an inch!
                            Feeling like you're on top of the world, you aren't the least bit scared.
                            You just took out a [b]monster[/b] of a human.
                            You're not scared of his two lackeys.
                            They can't aim for shit!
                        [/p]
                        [p]
                            You taunt the rock-toting skirmishers, telling them to get in the water so you can knock'em out like you did their leader.
                            One of the two men hasn't blown his load yet, however.
                            Instead of lamenting his boss' death, or getting emotional and firing without proper aim,
                            the slinger takes his time, clearing his head and focusing his [b]hatred[/b].
                            His mind zeroed in on you, he lets loose his more blunt stone, which flies towards you with a gentle arc.
                            Too busy laughing at them, you don't even [b]notice[/b] the heavy projectile until it's too late.
                        [/p]
                        [p]
                            The rock impacts heavily against your cranium.
                            You hear a loud [b]crack[/b], and it doesn't take a sharp mind to realize that it wasn't the stone that broke.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your worn out body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
