/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepOther(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ForestRiverKeepChoice.OTHER;
    var reqController = ctrl.keepGoing;
    var changeController = ctrl.otherSide;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextSceneName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverKnockedOut = true;
        var toReturn = `[p]
                            You need to conserve momentum, and keep going the way you were going!
                            The buff dude isn't going to be able to catch up, and you doubt his [i]friends[/i] are very skilled at using their weapons.
                            Ignoring the human's order for you to stop, you keep swimming forwards,
                            upping the pace to as fast as your frigid limbs can carry you,
                            changing from a doggy paddling to a full-on breaststroke technique.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hey! Did you hear me?![/color]"
                            [/big]
                        [/p]
                        [p]
                            The big brute's bass scream is loud enough to scare several birds from their nests,
                            an entire [b]flock[/b] dramatically bursting from the treeline-canopy.
                            He ups his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            His walking is nowhere near fast enough to keep up with you.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            [big]
                                "[color=green]What are you waiting for?! Shoot'em![/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the sharp rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile only [b]barely[/b] misses the semi-submerged leader's head,
                            whirring right by him, [b]plunging[/b] into the water directly in front of you.
                            Two near-hits, but it'll take more than a small splash getting water in your eyes to stop you.
                            Sheer adrenaline suppresses the immense fear that the bandits are more skilled than you'd have imagined.
                        [/p]
                        [p]
                            [big]
                                "[color=green]You almost hit [b]me[/b], you stupid idiot![/color]"
                            [/big]
                        [/p]
                        [p]
                            [big]
                                "[color=cyan]Do you want me to shoot the kobold or not?! Get out of the way![/color]"
                            [/big]
                        [/p]
                        [p]
                            And they say [b]kobolds[/b] are incapable of working together.
                            As the thugs bicker amongst eachother, you begin to near the riverbank, your salvation close at hand.
                            The slinger that hasn't yet hurled his load, releases his more bluntly shaped piece of stone, hurling it towards your head.
                            Like the other human before him, he missed you but [b]narrowly[/b],
                            his rock impacting against and bouncing off of a boulder sticking out from the river,
                            mere inches away from your face.
                            Driven by panic, you push your hypothermic body to its very limits,
                            squeezing every ounce of power from your frostbitten limbs to carry you forwards as quickly as you posssibly can go.
                        [/p]
                        [p]
                            Before the bandits gunning for you manage to load their second shots, and while the burly man isn't even [b]halfway[/b] across yet,
                            you finally reach the river's other shore.
                            Completely exhausted, you clamber out onto the riverbank, practically [b]collapsing[/b] into the shallow water.
                            But you're not done yet.
                            You're at the end of your rope, but if you stop now, this'll all have been for nothing.
                            You raise yourself to your hands and feet once more.
                            Lifting your head, you spot another group of humans directly in front of you, walking right at you.
                        [/p]
                        [p]
                            Like the clothes of the gang chasing you are dyed yellow,
                            this lot's more fancy attire is a bright purple.
                            A bowman, a crossbowman and a strongman with a large, two-handed sword.
                            The fellow with the bow has a fine moustache.
                            He's puffing smoke from a robust ${global.kobold.inventory.createItemWithTooltip(new SmokingPipe())}.
                            A gentleman down on his luck?
                        [/p]
                        [p]
                            For a moment, you fear these are two [b]very similar[/b] groups of the same gang,
                            but the sword-wielding goon soon debunks your suspicions.
                            "[color=purple]What the hell are you [b]copycats[/b] doing crossing the river?![/color]"
                            Two rival parties?
                            "[color=purple]Sending your [b]kobold spies[/b] over to [b]mimic[/b] us better?![/color]"
                        [/p]
                        [p]
                            Before you can explain that you're not with them, and before they can explain that they're not with you,
                            the crossbowman runs up to you, and harshly [b]kicks[/b] you in the side of the head,
                            the crushing impact of his heavy, leather boot sending you [b]flying[/b] backwards into the river.
                            Your brain shakes back and forth in your barely intact skull,
                            and before you can even [b]process[/b] the immense [b]pain[/b],
                            your weary body succumbs to unconsciousness.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("varanar_indoor_knockout");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
