/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepDownstreamSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.downstreamSuccess;
    
    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = "";
    
    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverEvaded = true;
        var toReturn = `[p]
                            Heading straight would be too predictable.
                            The two guys on the shore could easily hit you if you swim in a straight line.
                            Upstream, you'd be even [b]slower[/b].
                            A sitting duck.
                            That leaves only one way to go.
                            The sensible route.
                            The path of least resistance.
                            You need to head downstream.
                            Ignoring the human's order for you to stop, you suddenly take a hard left,
                            and instantly up your pace, swimming as fast as you can along with the current of the stream.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Hey! Did you hear me?![/color]"
                            [/big]
                        [/p]
                        [p]
                            You enter a small river-rapid.
                            The water's flow grips your featherweight body, pulling you along,
                            propelling you to [b]far[/b] greater speeds than you'd have been able to attain otherwise.
                            You feel like a [b]fish[/b], a [b]master[/b] of swimming, not to mention an [b]escape artist[/b] of the highest quality!
                            If you'd known the river could drive you onwards with such ease,
                            you would have used the current to escape a bunch of previous heists!
                        [/p]
                        [p]
                            [big]
                                "[color=green]The lizard's not listening. [b]Shoot it![/b][/color]"
                            [/big]
                        [/p]
                        [p]
                            The massive man's timid friends are quick to answer his command.
                            The slingshot-wielding human lets loose his weapon's taut-pulled string,
                            sending the sharp rock in between the two prongs [b]flying[/b] through the air.
                            The lethal projectile misses you by a wide margin,
                            your tiny frame [b]way[/b] too speedy for him to accurately fire at you.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Where did you learn how to aim?! Get it![/color]"
                            [/big]
                        [/p]
                        [p]
                            [big]
                                "[color=cyan]It's going too fast, damnit![/color]"
                            [/big]
                        [/p]
                        [p]
                            And they say [b]kobolds[/b] are incapable of working together.
                            As the two thugs bicker amongst eachother,
                            the slinger that hasn't yet hurled his load releases his more bluntly shaped piece of stone, hurling it towards your head.
                            Due to your current-driven acceleration, you've travelled [b]much[/b] too far for the projectile to even [b]reach[/b] you.
                            It harmlessly plunges into the water, quite a bit away.
                            Looks like you're in the clear!
                            Your plan worked perfectly!
                        [/p]
                        [p]
                            Then, turning your attention back to what's in front of you,
                            you suddenly remember why you [i]hadn't[/i] considered using the river to escape pursuers before.
                            Boulders.
                            Rocks.
                            [b]Sharp[/b] rocks.
                            A lot of them.
                            Directly in your path.
                            You're going too fast to avoid them completely!
                            You'll have to pull out some slick maneuvers if you want to make it out of this in one piece!
                        [/p]
                        ${global.ui.condSucc(`Agility above 5`)}
                        [p]
                            Contorting your body, you narrowly manage to avoid the first rock in your way.
                            While rapidly flailing your arms about, trying to fight the current and slow yourself down,
                            you dodge boulder after boulder, each one coming closer to hitting you than the last.
                            An oddly-shaped rock nearly pokes your eye out, but you manage to yank your head to the side just in time to avoid it.
                            Finally, after a frightening, life-threatening minute full of hazard and split-second decisions,
                            the rocky field clears out, and the river slows down once more.
                            You've survived.
                            For now.
                        [/p]
                        [p]
                            Thoroughly harrowed to the point of being traumatized, you slowly swim back over to the shore you came from.
                            It's too late to go to Varanar, and after barely surviving an adrenaline-fueled, high-stakes dodge-fest,
                            you'd much rather go back to your place to get some rest than scurry around the streets of a metropolis looking for a place to sleep.
                            You crawl ashore, and take a moment to catch your breath.
                            Escaping via the river -- [b]never again[/b].
                        [/p]
                        [p]
                            After calming down for a minute, you rise to your shaky feet,
                            and wearily stumble back into the forest proper.
                            Making sure to circumvent the group of thugs,
                            you begin to make your way back home.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
