/**
 * Swim section of the forest river.
 * @param {ForestRiverController} controller The Forest, River controller.
 */
function ForestRiverKeepUpstreamSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.upstreamSuccess;

    var nextSceneReady = ctrl.homeSceneReady;
    var nextSceneName = ctrl.homeSceneName;
    var nextFolderName = "";

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.forestToVaranar.riverEvaded = true;
        var toReturn = `[p]
                            They'll be expecting you to go downstream.
                            It's the easy route.
                            The path of least resistance.
                            What they [b]won't[/b] expect, is for you to fight [b]against[/b] the current.
                            They'll never see it coming.
                            You'll take them by surprise,
                            and you'll be gone long before they realize where you went.
                            Ignoring the human's order for you to stop, you take hold of the rock you were passing by,
                            and [b]pull[/b] yourself behind it, out of view.
                        [/p]
                        [p]
                            [big]
                                "[color=green]Playing hide and seek?! I'm coming to get you, lizard![/color]"
                            [/big]
                        [/p]
                        [p]
                            The big brute's bass shouting is loud enough to scare several birds from their nests,
                            an entire [b]flock[/b] dramatically bursting from the treeline-canopy.
                            He ups his stride, stepping through the water with large, determined paces.
                            While you are unable to stand, the human is tall enough to wade through the river,
                            the water reaching his enormous pecs, his manly nipples just below the surface.
                            It'd take a well filled up the brim to drown an [b]ogre[/b] his size.
                            His walking is slow enough for you to quickly devise a plan.
                            Does he even know how to swim?
                            You doubt it.
                        [/p]
                        [p]
                            That's it!
                            Your tiny size may be your salvation here.
                            You can [b]dive[/b] underneath the water, and make your way back towards the shore unseen!
                            If you can hold your breath for long enough,
                            you [i]should[/i] be able to reach the shore and make your getaway before they figure out where you went.
                            With the strong man rapidly approaching, you don't have much time to think things through.
                            You need to go.
                            You need to go [b]now[/b].
                        [/p]
                        [p]
                            Filling your frigid lungs with as much air as they can hold, you plunge your head underneath the water,
                            dive to the bottom of the river, and begin to make your way towards the shore from which you came,
                            aiming for a small alcove a bit further upstream, so you can circumvent the group of thugs.
                            While still hampering your progress, the current is quite a bit weaker at the riverbed than it was at the surface of the water.
                            By digging your claws into the mud, and clambering along the myriad of submerged rocks,
                            you manage to move quite a bit faster than you could while swimming.
                            You're slowly running out of air, but if you can keep up this pace, you might just make it out of here alive!
                        [/p]
                        [p]
                            [big]
                                "[color=green]It's gone!
                                Where the hell did that little cretin go?!
                                Look around, guys!
                                Can't be far![/color]"
                            [/big]
                        [/p]
                        [p]
                            Your disappearance being noted is the least of your concerns.
                            You're getting close to the shore, but as you pass by the pillars of the wooden bridge,
                            your drained lungs begin to [b]burn[/b], [b]begging[/b] you to come up for air.
                            Through sheer willpower and endurance alone, you keep clambering forwards along the bottom of the river,
                            your consciousness slowly waning as you get to ever-more shallow waters.
                            You black out for a minute, your mind lacking the oxygen needed to stay fully awake.
                        [/p]
                        ${global.ui.condSucc(`Endurance above 5`)}
                        [p]
                            When you come to, you find yourself lying on the riverbank.
                            You must have subconsciously pulled yourself ashore.
                            The burly man is still in the river looking for you, his comrades scouring the water's surface for any signs of their prey.
                            You want to take a moment to catch your breath,
                            but every second counts.
                            You scramble to your aching legs,
                            and wearily stumble back into the forest proper.
                        [/p]
                        [p]
                            You catch your breath without stopping, your stumbling gait turning into a proper walk,
                            and then an outright [b]jog[/b] as you hurry to get away from the thuggish trio.
                            They don't seem to be following you, probably still looking for you in the river.
                            Your ambition to get to Varanar before the end of the day completely [b]ruined[/b],
                            you head for your home in the woods,
                            hoping to be spared any further unpleasant encounters.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
