/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnLootUpstairsContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnLootUpstairsContinueButton";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dead = global.kobold.history.shared.cassidy.dead;
        var toReturn = `[p]
                            After about half an hour of running through fields, farms and small patches of woodland,
                            making sure to stay out of sight, you think you're finally in the clear.
                            By traversing less-well travelled paths, you've ensured nobody will be able to link you to 
                            ${dead ? "the murder" : "the robbing"} of Cassidy${dead ? "" : ", apart from the vixen herself"}.
                            ${dead ? "" : "You're certain she won't tell anyone, out of fear that you'll spread the word of her deviant sexual tastes, thus ruining her reputation."}
                            You have a feeling the city guards'll be pestering you enough [i]without[/i] allegations of ${dead ? "murder" : "robbery"}.
                        [/p]
                        [p]
                            You find yourself on the eastern road to Varanar once again.
                            You move the gold you stole from the small pouch it is in to your own moneybag.
                            After taking a moment to catch your breath, you begin to walk down the path towards the city.
                            At least you won't be meeting any more crazy, kobold-breeding bitches there.
                            Or so you hope.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnLootUpstairsContinue";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.postnotbarnloot.continued()) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.notbarnLootContinueChange();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.postnotbarnloot.continued()) {
            return;
        }

        //toEager.registerListeners();

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
