/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseWrestleChoke(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var continueId = arguments.callee.name + "ButtonOne";
    var next = new FarmerHouseWrestleChokeContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You remove your hand from the housewife's mouth, instantly wrapping your arm around her neck before she manages to utter a shout for help,
                            her attempts at a desperate plea reduced to a bunch of surprised gurgling noises as you squeeze her throat shut.
                            With her air supply cut off, the woman resumes her frantic struggling, even more intense than before.
                            While you've no intention of [i]killing[/i] her, [b]she[/b] doesn't know that.
                            Fearing for her very life, the human wildly writhes about, kicking her legs,
                            fighting against your grasp on her arms and wriggling her body from side to side in an effort to throw you off of her.
                        [/p]
                        [p]
                            While threatening violence doesn't seem to dissuade her this time,
                            you manage to keep the housewife firmly pinned down and in place throughout the entirety of her protests.
                            Merely half a minute after you began to choke her out, her floundering slowly begins to die down,
                            until her body finally slumps down to the ground, unconsciousness setting in.
                            You could very well [b]kill[/b] her, but you're a [b]thief[/b], and not a murderer.
                            You'd have preferred if things didn't get this [i]physical[/i] to begin with.
                        [/p]
                        [p]
                            The woman knocked out, you rise to your feet and take a quick breather.
                            You doubt she'll be out for long, however.
                            You need to get to looting this place, and fast.
                        [/p]
                        [p]
                            You step into the dining room.
                            Nothing worth a damn in here, at first glance.
                            You keep moving, entering the living room, or at least what's supposed to pass for it.
                            The room is dominated by a single padded chair, the most comfortable piece of furniture you've come across in the house, so far.
                            It stands before a small fireplace, probably the only source of [i]warmth[/i] apart from the oven in the kitchen.
                            Still, nothing interesting to take.
                        [/p]
                        [p]
                            There's only one room left, which you assume to be the bedroom.
                            Opening the shabby wooden door, your suspicions are confirmed.
                            Two beds.
                            A big one, and a small one.
                            A dresser, and a nightstand.
                            You decide to go for the latter.
                        [/p]
                        [p]
                            Opening the small drawer, you are surprised to find that it [b]isn't[/b] full of underwear.
                            Instead, the nightstand contains a pair of worn books,
                            atop which lay some out-of-place looking ${global.kobold.inventory.createItemWithTooltip(new FancyGlasses())}.
                            Your eyes open wide, avarice surging to a whole new level.
                            This find more than makes up for having to deal with the housewife.
                            If you knew these farmers had something [b]this[/b] expensive laying around,
                            you wouldn't have stopped attempting to steal from them after your first attempt.
                        [/p]
                        [p]
                            You figure they must be a family heirloom or something.
                            Regardless, they're [b]yours[/b] now.
                            You pocket the valuable item, and start thinking of a way out of this place.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.choke.continued() ? "disabled" : "";
        var isSelected = ctrl.choke.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.choke.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if(ctrl.wrestle.get() !== FarmerHouseWrestleSuccessChoice.CHOKE) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.choke.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if(ctrl.wrestle.get() !== FarmerHouseWrestleSuccessChoice.CHOKE) {
            return;
        }
        
        next.registerListeners();

        if (ctrl.choke.continued()) {
            return;
        }

        registerNextListener();
    };
}
