/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseInside(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var cabinetId = arguments.callee.name + "ButtonOne";
    var followId = arguments.callee.name + "ButtonTwo";

    var toCabinet = new FarmerHouseCabinet(ctrl);
    var toFollow = new FarmerHouseFollow(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Going to the shed would be a dumb idea.
                            There's probably [b]nothing[/b] of value in there.
                            At least in here, there might be [b]something[/b] worth stealing.
                            Still, it's not going to be easy with the human in the kitchen.
                        [/p]
                        [p]
                            Then, as though your prayers were heard, a miracle happens.
                            Footsteps, once more.
                            You peek out from behind the cabinet, just in time to spot the woman leaving the kitchen, a pair of sandwiches in hand.
                            You wait for a few moments to see if she might return, but she doesn't.
                            You hear her putting down what you presume to be a pair of metallic plates in an adjacent room, probably the dining room or the den.
                        [/p]
                        [p]
                            Your way further into the house is cleared.
                            You [b]knew[/b] staying indoors was the correct way to go about things!
                            But still, this isn't the time to get cocky.
                            The woman may have left the kitchen, but she's still around.
                            It'd be a shame if you [i]bumped[/i] into her after all this stressful waiting and careful planning.
                            If you want to play it safe, you could simply see what the cabinet you've been hiding behind contains.
                            Following the woman as she goes about her business is a more [i]risky[/i] strategy,
                            but it still beats randomly roaming about the house in both security and stealing potential.
                            The human can't see you if you're behind her back, after all.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildCabinetChoice() {
        var disabled = ctrl.inside.has() ? "disabled" : "";
        var isSelected = ctrl.inside.get() === FarmerHouseInsideChoice.CABINET;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${cabinetId}" ${disabled} style="width:180px;">Rob the cabinet</button>`;

        var tooltip = global.parser.parse(`Steal from the cabinet.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:180px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFollowChoice() {
        var disabled = ctrl.inside.has() ? "disabled" : "";
        var isSelected = ctrl.inside.get() === FarmerHouseInsideChoice.FOLLOW;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${followId}" ${disabled}>Follow her</button>`;

        var tooltip = global.parser.parse(`Follow the woman around and take what you can along the way.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildFollowChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildCabinetChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + cabinetId), $("#" + followId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerCabinetListener() {
        $("#" + cabinetId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.inside.set(FarmerHouseInsideChoice.CABINET);
            loadNextPart(toCabinet);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFollowListener() {
        $("#" + followId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.inside.set(FarmerHouseInsideChoice.FOLLOW);
            loadNextPart(toFollow);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.steal.get() !== FarmerHouseStealChoice.INSIDE) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toCabinet.build();
        part += toFollow.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.steal.get() !== FarmerHouseStealChoice.INSIDE) {
            return;
        }

        toCabinet.registerListeners();
        toFollow.registerListeners();

        if (ctrl.inside.has()) {
            return;
        }

        registerCabinetListener();
        registerFollowListener();
    };
}

var FarmerHouseInsideChoice = {
    CABINET: 1,
    FOLLOW: 2
};

