/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbSucceed(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.climbSucceed;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After your depressing train of thoughts, you decide it's time to inspect the well more thoroughly.
                            There might be some coins at the bottom, and who knows what else you might find?
                            Some good old adventuring is exactly what you need to lift your spirits.
                        [/p]
                        [p]
                            You figure you might be able to scale down the cobblestone wall.
                            There's plenty of rocks sticking out, and like you noticed earlier,
                            the lime in between the stones is soft enough for you to carve your claws into, should the need arise.
                            While you're no expert in climbing, you've scaled many trees and even a couple of buildings before.
                            You're certain this'll go fine, but still, you're more than a little scared of the dark depths that await you.
                        [/p]
                        [p]
                            Gathering your courage, you let out a determined grunt.
                            Knights are fearless, and if you want to be one, you can't shy away from adventure.
                            You need to plunge head-first into danger!
                            Well, maybe not head-first, but you still need to go down the well,
                            if just to prove to yourself that you [b]do[/b] have what it takes to stop being a thief one day.
                        [/p]
                        [p]
                            You hop on top of the well's edge.
                            Facing away from the watering hole, you squat down.
                            With both your hands, you take hold of the rim of the cobblestone wall.
                            You let out a deep, nerve-soothing sigh.
                            Here you go.
                        [/p]
                        [p]
                            You lower your body into the watering hole, hanging off your hands until you can find a good place to put your feet.
                            At first, you only find [b]one[/b] rock sticking out within your reach, and it doesn't seem to be a very stable one.
                            Stretching your agile body to its very limits, however, you discover a second, far more stable stone platform just a few inches lower.
                            You place one of your feet down onto the rock, and with the first step made, you begin your descent proper.
                        [/p]
                        [p]
                            You deftly climb down the entire height of the circular cobblestone wall.
                            More than once do you find yourself in a perilous situation, but despite the well itself falling apart at the seams,
                            you manage to stick to the wall all the way to the bottom, where you lower your lithe frame into the cool water.
                            The water's too deep for you to stand up right.
                            Your gently kicking legs and your arms slowly rocking back and forth along the surface of the water keep your light frame afloat.
                            The damp, stale air at the bottom of the well is of poor quality,
                            but at least keeping yourself from sinking takes less effort than climbing down did.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 5`)}
                        [p]
                            You take a moment to recover from the strenuous climb.
                            You're glad and proud that you made it all the way down without falling.
                            A good display of flexibility, that you're certain not everyone can match.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you have to climb all the way back [b]up[/b] to get out of this place.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}
