/**
 * Approachj section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeApproach(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var refuseId = "savedRefuseButton";
    var giveId = "savedGiveButton";
    
    var toRefuse = new HomeRefuse(ctrl);
    var toGive = new HomeGive(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide [b]not[/b] to fuck around and to simply approach the man and have a reasonable, civil conversation with him.
                            He takes note of you as you draw near, rising from his treestump-seat, towering a good foot above you, 
                            undoubtedly weighing multiple times your own mass.
                        [/p]
                        [p]
                            "[color=brown][b]You're late.[/b][/color]" the brute speaks, before crudely scratching his bulging belly.
                            He eyes your meagre frame up and down.
                            Noticing the coin-filled pouch hanging off your neck, the fat lizard rudely points one of his chubby fingers at it.
                            "[color=brown][b]That's what I'm here for.[/b][/color]"  he continues, turning his pointing hand into a receiving cup.
                            "[color=brown][b]Rat wants his money. Hand it over.[/b][/color]" 
                            The enforcer's other hand balls up into a menacingly raised fist.
                            "[color=brown][b]Or else.[/b][/color]" 
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the refuse choice button.
     */
    function buildRefuseChoice() {
        var disabled = ctrl.saved.debt.has() ? "disabled" : "";
        var isSelected = ctrl.saved.debt.get() === HomeApproachChoice.REFUSE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${giveId}" ${disabled}>Hand it over</button>`;

        var tooltip = `Give him your purse.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the give choice button.
     */
    function buildGiveChoice() {
        var disabled = ctrl.saved.debt.has() ? "disabled" : "";
        var isSelected = ctrl.saved.debt.get() === HomeApproachChoice.ACCEPT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${refuseId}" ${disabled}>Refuse</button>`;

        var tooltip = `Shake your head no.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildRefuseChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildGiveChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + refuseId), $("#" + giveId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerRefuseListener() {
        $("#" + refuseId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.set(HomeApproachChoice.REFUSE);
            loadNextPart(toRefuse);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerGiveListener() {
        $("#" + giveId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.set(HomeApproachChoice.ACCEPT);
            loadNextPart(toGive);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeApproach";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.TALK) {
            return "";
        }
        global.ui.applyTheme("home");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toRefuse.build();
        part += toGive.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.TALK) {
            return;
        }

        toRefuse.registerListeners();
        toGive.registerListeners();

        if (ctrl.saved.debt.has()) {
            return;
        }

        registerRefuseListener();
        registerGiveListener();
    };
}

var HomeApproachChoice = {
    REFUSE: 1,
    ACCEPT: 2
};
