/**
 * Arrival section of Varanar, Afternoon Three.
 * @param {AfternoonThreeController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeArrivalChoice.KOBOLD;
    var reqController = ctrl.arrival;
    var subController = ctrl.entrance;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new AfternoonThreeRuby(ctrl);
    var secondNext = new AfternoonThreeDistrict(ctrl);

    var firstChoice = AfternoonThreeEntranceChoice.INVESTIGATE;
    var secondChoice = AfternoonThreeEntranceChoice.IGNORE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Time to take a break from all the humans.
                            You've seen enough of them, for a while.
                            A trip to the kobold district'll do you well.
                            Some time to spend amongst your peers, instead of those who look down upon you.
                            Then again, even within the ranks of the kobolds, there are those who don't exactly see you as equal.
                            The Three-Tailed Rat Clan, for starters.
                            You really hope you don't run into them.
                            But what are the odds of that, right?
                        [/p]
                        [p]
                            There is a visible change in scenery as you cross from human territory into the kobold neighbourhood.
                            The streets grow more narrow and the buildings change from masoned houses to shacks made out of metal and wood,
                            varying heavily in size, shape, durability and height.
                            Various tarps, rugs,
                            clothing hung out to dry, and ramshackle catwalks connecting the low-hanging rooftops of the buildings,
                            all work together to [b]block[/b] most of the sunlight, making the ground-level dim and dark.
                            Permanent twilight, interrupted by a few rays of light shining through cracks and holes up above.
                            It's actually kind of pretty, in a way only a kobold could understand.
                        [/p]
                        [p]
                            The kobold district is a big place, teeming with little lizards just like yourself.
                            As you stroll deeper into the neighbourhood, you cross paths with people dressed like thieves,
                            bandits, manual labourers, scantily-clad whores, naked beggars and a few more shady looking fellows.
                            You pass by stores ran by kobolds selling scraps and stolen goods,
                            you witness gangs of children running wild, clearly out to pickpocket unsuspecting victims,
                            various couples openly kissing and fucking in the streets,
                            and a few heated arguments that felt like they were moments away from escalating into full-on fights.
                            Lots of sights to see, but nothing particularly inviting enough for you to involve yourself with.
                        [/p]
                        [p]
                            Less than half an hour into your exploratory trek, a shrill shriek suddenly resounds throughout the narrow streets.
                            While there have been plenty loud noises since you've entered this district,
                            from merchants praising their own wares to slutty moans from kobolds fucking to catcalls aimed at those who are [i]not[/i],
                            none sounded quite as [i]distressed[/i] as this shout for help.
                            Someone in trouble, perhaps?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Investigate</button>`;

        var tooltip = global.parser.parse(`Who's screaming? What's happening? Go check it out!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 195px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} disabled>Ignore</button>`;

        var tooltip = global.parser.parse(`Probably some idiot who walked into the wrong neighbourhood. [todo]Unavailable[/todo]`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_alley");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        //part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        //secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        //registerSecondListener();
    };
}

var AfternoonThreeEntranceChoice = {
    INVESTIGATE: 1,
    IGNORE: 2
};
