/**
 * Ruby section of Varanar, Afternoon Three.
 * @param {AfternoonThreeRubyController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeInvestigateScreamLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeInvestigateScreamChoice.LEAVE;
    var reqController = ctrl.scream;
    var changeController = ctrl.screamLeave;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var his = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            To be honest, you can't blame the thief for ditching the locket in your hands.
                            With the dragoness causing such a fuss, you can understand why ${his ? `he` : `she`} wanted to bail.
                            The woman is clearly hysterical.
                            Who knows what she'd do if she saw you with the locket in your [i]lowborn[/i] hands?
                            You, too, should probably get out of here while you still can.
                            [i]Before[/i] she notices you.
                        [/p]
                        [p]
                            You turn around, and walk the opposite direction, back the way you came.
                            Feeling a little [i]unsafe[/i] brandishing such a valuable item in a [i]shady[/i] district like this one,
                            you decide to leave the neighbourhood as quickly as you can.
                            Through the various overhead obstructions and light-blocking fabrics,
                            you notice the sky is slowly turning dark, and the sun is starting to set.
                            The afternoon is turning into an early winter night.
                        [/p]
                        [p]
                            Leaving the kobold district behind you, you head for the mercantile quarter,
                            hoping to either find a place to pawn off the locket,
                            or just somewhere warm to spend the night.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }


        global.ui.imageBackground.hide();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
