/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatChoice.OFFER;
    var reqController = ctrl.eat;
    var subController = ctrl.offer;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenEatMention(ctrl);
    var secondNext = new VaranarSoupKitchenEatNoMention(ctrl);

    var firstChoice = VaranarSoupKitchenEatOfferChoice.MENTION;
    var secondChoice = VaranarSoupKitchenEatOfferChoice.DONOT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.gaveHouse = true;
        var toReturn = `[p]
                            At first, you can't really think of a way to console the man.
                            Then, suddenly, something comes to mind.
                            You're carrying a thing that might help.
                            A key.
                            ${global.kobold.inventory.createItemWithTooltip(new CassidyHouseKey())}.
                            You produce the small, metal object and slide it over the surface of the table towards the caprine.
                        [/p]
                        [p]
                            "[color=ppink]What's this?[/color]"
                            he asks, curiously picking your gift up from the table.
                            You explain that it's a [i]key[/i].
                            "[color=ppink]Ah know what ah key is, ye smartass.
                            What's it for?[/color]"
                            A house in the hamlet outside of town, you reply.
                            A [i]mansion[/i], more like.
                            The man eyes you suspiciously.
                            "[color=ppink]And what's that got tah do with me?[/color]"
                        [/p]
                        [p]
                            You explain that you don't really [b]need[/b] a mansion.
                            You have a shack in the woods, and you're content with that.
                            You could [b]give him[/b] the house, and he could continue his business there, if he'd like.
                            On one [i]condition[/i], that is.
                            There's a bunch of kobolds trapped in a barn attached to the house.
                            If he promises to free them and feed them, then by all means, he can have the place.
                        [/p]
                        [p]
                            You notice a twinkle of [i]hope[/i] flare up in the sheep's eyes.
                            Still, he remains wary.
                            "[color=ppink]And how'd [b]you[/b] get this [i]mansion[/i]?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Mention</button>`;

        var tooltip = global.parser.parse(`Mention there [i]might[/i] be a dead vixen present.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Do not</button>`;

        var tooltip = global.parser.parse(`He'll find out about Cassidy's corpse eventually. [i]If[/i] it's still there.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenEatOfferChoice = {
    MENTION: 1,
    DONOT: 2
};
