

// SCENE HamletWell

// scenes\HamletDay2\HamletWell\bottom\stuck\HamletWellStuck.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellStuck(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preContinue;
    var changeController = false;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var help = ctrl.down.get() === HamletWellFallChoice.HELP;
        var toReturn = `[p]
                            The shaking intensifies.
                            You narrowly dodge a few bigger chunks of cobblestone falling down from the near-collapsing wall.
                            Pebbles rain on your head and plummet into the water besides you like an intense, earthen [i]hailstorm[/i].
                            You need to [b]get out of here[/b] and you need to do so [b]fast[/b]!
                            You can't climb, not with this entire place coming down on you.
                            You could dive, but that would mean you'd get buried slowly instead of getting knocked out by a piece of debris.
                            You scream for help${help ? ` again` : ``}, but nobody comes to your aid.
                            Is this well to be your grave?
                        [/p]
                        [p]
                            Panicking, you look all around, for [b]any[/b] way out of this soon-to-be [b]coffin[/b].
                            Then, out of the corner of your eye, you spot what might be your salvation.
                            A small hole in the side of the well, directly underneath the surface of the water,
                            one barely big enough for you to squeeze through.
                            You aren't sure whether that was always there, or if the earthquake uncovered it just now, but you aren't going to question it.
                            You don't even know whether it leads [i]anywhere[/i], but you'd rather die drowning trying to save your own hide,
                            than simply standing here cowering and waiting for your own death.
                        [/p]
                        [p]
                            The well looks about ready to collapse, bigger and bigger pieces of cobblestone breaking off from the wall,
                            dirt starting to seep in from the holes left behind.
                            Taking a deep breath, one that may be your very last one [b]ever[/b],
                            you dive underwater, and you squeeze through the rough stone gap,
                            your belly and your back both chafing against the coarse rocks, your tail only [b]barely[/b] managing to fit.
                        [/p]
                        [p]
                            The moment your feet disappear into the crevice, the well collapses fully behind you, barring your way back,
                            debris falling so close it nearly scrapes your soles.
                            The underwater hole seems to lead to a tiny, submerged tunnel!
                            You only hope it will actually take you somewhere you can [b]breathe[/b],
                            instead of being blocked off at one point or another.
                            You may not have been buried alive, but you're not nearly out of danger yet.
                            Already starting to run out of air, you swim forwards, into the unknown.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\HamletDay2\HamletWell\bottom\stuck\HamletWellStuck.js

// scenes\HamletDay2\HamletWell\bottom\swim\HamletWellPants.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellPants(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.pants;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You may not have wanted to go down this damp hole, but now that you're here, you might as well explore it fully.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, and you're not going to back down just because the air in here is a little stale.`;
            if (rocky) {
                arrivalDescriptor = `Your entrance might not have been very [i]graceful[/i], `;
                arrivalDescriptor += `but you're not going to let a single small setback dissuade you from properly exploring this damp hole.`;
            }
        }
        var toReturn = `[p]
                            You don't concern yourself with escaping the well just yet.
                            ${arrivalDescriptor}
                            You take a few deep breaths, filling your ${drowned ? `still slightly aching` : ``} lungs with as much air as they can possibly hold.
                            Steeling your nerves, you dip your head
                            underwater${rocky ? ` yet again` : ``}${drowned ? `, your mind working overtime to suppress flashbacks
                            from your near-death experience just a few minutes ago` : ``}.
                            Athletically lifting the lower half of your body upwards, while simultaneously sinking your torso deeper,
                            you dive down and submerge yourself completely.
                        [/p]
                        [p]
                            With your eyes having adapted to the dark, and all kobolds luckily being able to see underwater,
                            you immediately notice something dinstinctly [b]shiny[/b] at the bottom of the well.
                            Coins, perhaps?
                            Maybe ${wanted ? `coming down here wasn't such a bad idea after all` : `falling down here wasn't such a bad thing after all`}.
                        [/p]
                        [p]
                            You swim down further, until you suddenly feel a dull scraping at the side of your leg.
                            Looking upwards, you find out that your thigh accidentally rubbed along a sharp rock protruding
                            from the edge of the well${rocky ? `, one you were lucky enough to miss on your earlier way down, ` : ``} without you noticing.
                            Thankfully, your ${global.kobold.inventory.createItemWithTooltip(pants)} protected your scaly hide.
                        [/p]
                        [p]
                            You were so focussed on the promise of gold that you momentarily forgot you're swimming around in a decrepit, age-old well.
                            You don't think the people that made this thing were too concerned about kobolds swimming around in it thousands of years in the future.
                            Alas, your ${global.kobold.inventory.createItemWithTooltip(pants)} were completely [b]torn apart[/b] by the unfortunate scraping.
                            You steer clear of the sharp rock, tear off the remnants of your pants and toss them to the side, letting them float to the bottom of the well.
                            If that [i]is[/i] gold you spy, you'll be able to buy a new pair later.
                        [/p]
                        [p]
                            With your ruined pants discarded, you continue swimming downwards.
                            A few strokes later, you arrive at the muddy ground.
                            To your pleasant surprise, the glint you saw from afar was indeed a shiny coin!
                            And it's not alone.
                            Brushing off some of the mud, you find piece after piece of gold, probably tossed down here by farmers wishing for good fortune.
                            Their prayers were answered, maybe not for them, but at least for you.
                        [/p]
                        [p]
                            You pick through the watery dirt, scrounging as many coins as you can before needing to go up for air.
                            Making sure to avoid hitting the same sharp stone again, you flip yourself upright once more,
                            kick off from the muddy ground, and swim back up to the surface.
                        [/p]
                        [p]
                            Surfacing from your dive, you take a closer look at the armful of coins you salvaged.
                            Most of them are coated with years worth of dirt.
                            You take the time to individually rinse them off in the water, before inspecting them further.
                            They seem to be pretty old, engraved with a design you've never quite seen before.
                            Oh well, you're certain they're still good for use.
                        [/p]
                        [p]
                            You notice that none of the coins have rusted,
                            despite being underwater for what you can only imagine to be quite a long time.
                            Come to think of it, you've never actually seen a rusty piece of gold.
                            You think that perhaps gold [i]can't[/i] rust, but you're not quite certain.
                            It would make sense to make money out of something that can't fall prey to the elements, right?
                            You briefly wonder why people don't make [i]unrustable[/i] weapons out of gold,
                            but you know pretty much nothing of smithing [i]or[/i] weaponry,
                            so you quickly drop the topic and get to work putting the coins into your pouch.
                        [/p]
                        [p]
                            Right as you were about to dive down a second time to gather more shinies, a loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\swim\HamletWellPants.js

// scenes\HamletDay2\HamletWell\bottom\swim\HamletWellScrape.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellScrape(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.scrape;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.scrapedThigh = true;
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You may not have wanted to go down this damp hole, but now that you're here, you might as well explore it fully.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, and you're not going to back down just because the air in here is a little stale.`;
            if (rocky) {
                arrivalDescriptor = `Your entrance might not have been very [i]graceful[/i], `;
                arrivalDescriptor += `but you're not going to let a single small setback dissuade you from properly exploring this damp hole.`;
            }
        }
        var toReturn = `[p]
                            You don't concern yourself with escaping the well just yet.
                            ${arrivalDescriptor}
                            You take a few deep breaths, filling your ${drowned ? `still slightly aching` : ``} lungs with as much air as they can possibly hold.
                            Steeling your nerves, you dip your head
                            underwater${rocky ? ` yet again` : ``}${drowned ? `, your mind working overtime to suppress flashbacks
                            from your near-death experience just a few minutes ago` : ``}.
                            Athletically lifting the lower half of your body upwards, while simultaneously sinking your torso deeper,
                            you dive down and submerge yourself completely.
                        [/p]
                        [p]
                            With your eyes having adapted to the dark, and all kobolds luckily being able to see underwater,
                            you immediately notice something dinstinctly [b]shiny[/b] at the bottom of the well.
                            Coins, perhaps?
                            Maybe ${wanted ? `coming down here wasn't such a bad idea after all` : `falling down here wasn't such a bad thing after all`}.
                        [/p]
                        [p]
                            You swim down further, until you suddenly feel a sharp, stinging [b]pain[/b] at the side of your leg.
                            Looking upwards, you find out that your thigh accidentally rubbed along a sharp rock protruding
                            from the edge of the well${rocky ? `, one you were lucky enough to miss on your earlier way down, ` : ``} without you noticing.
                            Blood flows liberally from your upper leg, painting part of the water an ever-darkening shade of red.
                            It seems that the pain is only now starting to fully set in.
                            You clutch your thigh, wincing and letting out an underwater [b]scream[/b] out of sheer pain.
                        [/p]
                        [p]
                            You were so focussed on the promise of gold that you momentarily forgot you're swimming around in a decrepit, age-old well.
                            You don't think the people that made this thing were too concerned about kobolds swimming around in it thousands of years in the future.
                            Money be damned, your leg hurts [b]far[/b] too much to continue downwards.
                            Making sure to avoid hitting the same sharp stone again, you flip yourself upright once more, and swim back up to the surface.
                        [/p]
                        [p]
                            Surfacing from your dive, you take a closer look at the wound you sustained.
                            It's a pretty [i]lengthy[/i] gash, running along the upper half of your outer thigh towards your rear,
                            stopping inches before reaching your butt proper.
                            While you don't think it's a very [i]deep[/i] cut, you're still bleeding like a stuck pig,
                            tainting the clear, ${drank ? `sedating` : `fresh`} water with kobold blood.
                        [/p]
                        [p]
                            As if to make matters even worse, a loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\swim\HamletWellScrape.js

// scenes\HamletDay2\HamletWell\bottom\help\beg\HamletWellBegSucceed.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellBegSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.helpBegSucceed;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.escapedRope = true;
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You say it's a good thing the boys found you when they did.
                            You were about to give up hope before they showed up!
                            You, uh, fell down here and you can't seem to get out on your own.
                            You ask them if they could, pretty please, perhaps toss down a rope attached to something so you can climb out of here,
                            or maybe go get one of their parents to help you out or something?
                        [/p]
                        [p]
                            You get the feeling the boys weren't exactly paying attention to your desperate pleading,
                            or maybe they're just not taking you very serious.
                            Althroughout your [i]begging for help[/i], you could hear them utter snickers and sneers, giggles and chortles,
                            like they were joking around instead of listening to you.
                            "[color=red]Hey![/color]" finally comes a response, after a moment of silence.
                            "[color=red]When kobolds are left in the water for too long, do they turn into fish?[/color]"
                        [/p]
                        [p]
                            More laughter.
                            They sound like they're having the time of their lives picking on you,
                            maybe because nothing interesting [i]ever[/i] happens around these parts.
                            Once they're done teasing you, surely, they'll come to your aid, right?
                            They wouldn't just leave you here, would they?
                        [/p]
                        [p]
                            Desperation growing at the back of your head, you decide to play along with the boys' little [i]game[/i].
                            You reply that, no, you don't turn into a fish, but you might become a scary crocodile if they don't let you out soon!
                            "[color=blue]A crocodile?[/color]" answers the third child, in a satirical tone.
                            "[color=blue]A kobold like you is more likely to turn into an [i]alley-gay-whore[/i]![/color]"
                        [/p]
                        [p]
                            The audacity!
                            Where does a young boy even pick up such vulgar words?!
                            All three begin to cackle loudly, laughing their asses off at the third boy's joke.
                            Stupid inbred farmer hicks not raising their kids right.
                            The laughter goes on for the better half of a minute.
                            You're starting to lose your patience with these kids.
                        [/p]
                        [p]
                            The laughter slowly dies down.
                            All three of the kids' heads turn towards the same direction.
                            "[color=red]We're being careful, mom![/color]"
                            You overhear one of the boys replying to who you can only imagine to be his mother.
                            "[color=red]Fiiiine! Let's go.[/color]"
                        [/p]
                        [p]
                            Without even giving you a proper goodbye,
                            and more importantly: without telling this [i]mother[/i] figure about the [b]kobold trapped in the well[/b],
                            the boys hop off of the edge of the well, and disappear from sight.
                            You shout for them to come back, to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Calling for help clearly won't get you anywhere.
                            If the children of the hamlet won't help you, then you have little hope for the adults.
                        [/p]
                        [p]
                            Suddenly, a rope falls into the water, right next to you.
                            Wait, what?
                            A rope?
                            Where did that come from?!
                            You look upwards, but you see nobody there.
                            How weird.
                            You give the cord a tug.
                            It seems to be secured to something.
                            That means you can use it to climb out!
                            Someone just [b]saved[/b] you!
                        [/p]
                        ${global.ui.condSucc(`Charisma greater than 5`)}
                        [p]
                            Maybe one of the kids [b]did[/b] care, or perhaps a random passerby decided to help you out.
                            Regardless, you don't have much time to think things over. 
                            If you wait too long, something [i]bad[/i] might happen to [b]ruin[/b] your one and only hope of getting out of here.
                            Something bad [b]always[/b] happens.
                        [/p]
                        [p]
                            But not this time.
                            You're not going to take any chances sitting here pondering just [i]who[/i] it was that came to your rescue.
                            You'll see for yourself when you get out of the well.
                            You immediately grab the rope, and begin to shimmy upwards, towards your freedom.
                        [/p]
                        [p]
                            While the climb is exhausting, at least the rope makes it somewhat bearable.
                            You press your feet against the wall, and vertically walk to safety, pulling yourself upwards one step at a time.
                            A few minutes later, you find yourself at the very top, and after climbing over the small above-ground portion of the well,
                            your feet plop down on steady ground once more.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have escaped the well!
                                [/b]
                            [/c]
                        [/p]
                        [p]
                            After dropping to your knees and only [i]barely[/i] preventing yourself from kissing the dirt out of sheer joy,
                            you stand up and look for your oh-so kind benefactor.
                            However, there is nobody to be found.
                            The hamlet looks as deserted as it did the moment you entered it.
                        [/p]
                        [p]
                            You are left with more questions than answers.
                            Who saved you?
                            Was it one of the kids?
                            A farmer?
                            A random, compassionate guard passing by the area?
                            You're glad you got out, but you'd at least like to [b]thank[/b] whoever helped you.
                            Alas, it seems your [i]sympathizer[/i] wishes to remain anonymous.
                            A shame.
                        [/p]
                        [p]
                            With mixed feelings, you decide you've stuck around the hamlet for too long already.
                            It's time to get moving.
                            If you hurry, you might still make it to Varanar before nightfall.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\help\beg\HamletWellBegSucceed.js

// scenes\HamletDay2\HamletWell\bottom\help\beg\HamletWellBegFail.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellBegFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.helpBegFail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You say it's a good thing the boys found you when they did.
                            You were about to give up hope before they showed up!
                            You, uh, fell down here and you can't seem to get out on your own.
                            You ask them if they could, pretty please, perhaps toss down a rope attached to something so you can climb out of here,
                            or maybe go get one of their parents to help you out or something?
                        [/p]
                        [p]
                            You get the feeling the boys weren't exactly paying attention to your desperate pleading,
                            or maybe they're just not taking you very serious.
                            Althroughout your [i]begging for help[/i], you could hear them utter snickers and sneers, giggles and chortles,
                            like they were joking around instead of listening to you.
                            "[color=red]Hey![/color]" finally comes a response, after a moment of silence.
                            "[color=red]When kobolds are left in the water for too long, do they turn into fish?[/color]"
                        [/p]
                        [p]
                            More laughter.
                            They sound like they're having the time of their lives picking on you,
                            maybe because nothing interesting [i]ever[/i] happens around these parts.
                            Once they're done teasing you, surely, they'll come to your aid, right?
                            They wouldn't just leave you here, would they?
                        [/p]
                        [p]
                            Desperation growing at the back of your head, you decide to play along with the boys' little [i]game[/i].
                            You reply that, no, you don't turn into a fish, but you might become a scary crocodile if they don't let you out soon!
                            "[color=blue]A crocodile?[/color]" answers the third child, in a satirical tone.
                            "[color=blue]A kobold like you is more likely to turn into an [i]alley-gay-whore[/i]![/color]"
                        [/p]
                        [p]
                            The audacity!
                            Where does a young boy even pick up such vulgar words?!
                            All three begin to cackle loudly, laughing their asses off at the third boy's joke.
                            Stupid inbred farmer hicks not raising their kids right.
                            The laughter goes on for the better half of a minute.
                            You're starting to lose your patience with these kids.
                        [/p]
                        [p]
                            The laughter slowly dies down.
                            All three of the kids' heads turn towards the same direction.
                            "[color=red]We're being careful, mom![/color]"
                            You overhear one of the boys replying to who you can only imagine to be his mother.
                            "[color=red]Fiiiine! Let's go.[/color]"
                        [/p]
                        [p]
                            Without even giving you a proper goodbye,
                            and more importantly: without telling this [i]mother[/i] figure about the [b]kobold trapped in the well[/b],
                            the boys hop off of the edge of the well, and disappear from sight.
                            You shout for them to come back, to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Calling for help clearly won't get you anywhere.
                            If the children of the hamlet won't help you, then you have little hope for the adults.
                        [/p]
                        ${global.ui.condFail(`Charisma below 6`)}
                        [p]
                            Halfway through conceiving an intricate escape plan concerning your tail and a star-shaped rock of some kind,
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\help\beg\HamletWellBegFail.js

// scenes\HamletDay2\HamletWell\bottom\help\HamletWellBeg.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellBeg(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellHelpChoice.BEG;
    var reqController = ctrl.help;

    var toFail = new HamletWellBegFail(ctrl);
    var toSuccess = new HamletWellBegSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.charisma() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\HamletDay2\HamletWell\bottom\help\HamletWellBeg.js

// scenes\HamletDay2\HamletWell\bottom\help\HamletWellScold.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellScold(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellHelpChoice.SCOLD;
    var reqController = ctrl.help;
    var subController = ctrl.preContinue;
    var changeController = ctrl.helpScold;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You tell the boys that they should mind their manners.
                            They can't just go around calling random people dumb!
                            Now, they should go get their parents, and if they're super nice to you,
                            you won't even tell the grown-ups what their children called you.
                        [/p]
                        [p]
                            For a moment, the trio goes silent.
                            While you can't quite tell from where you are [i]swimming[/i],
                            you can imagine them staring at one another in disbelief.
                            Any minute now, they'll apologize, and go fetch some farmers to get you out of here.
                            "[color=red]Hey![/color]" finally comes a response.
                            "[color=red]Since the kobold likes water so much, how about I give it some more?[/color]"
                        [/p]
                        [p]
                            [i]Give you some more?[/i]
                            What does that even mean?
                            Are they going to pour water down the well?
                            "[color=blue]No, Leif, your mom said you weren't allowed to pee in the well![/color]"
                            Wait, what?
                            [i]Pee in the well?[/i]
                            "[color=red]Yeah, but she never said anything about peeing on kobolds![/color]"
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            From all the way at the top, a thin stream of watery urine sprays down into the well.
                            Due to the remarkable distance between the two of you,
                            the boy mostly ends up doing nothing but splattering the cobblestone wall with pee.
                            A few droplets, manage to make into the water next to you, but you never get hit directly by the troublesome youth.
                        [/p]
                        [p]
                            The stream soon comes to an end, the echoing sound of the tiny flow of splattering piss replaced by your loud, angry hissing,
                            which, in turn, is overshadowed by the trio's building, booming laughter.
                            "[color=red]That enough for you, lizard?![/color]"
                            One of them shouts down at you.
                            You curse your lungs out at them, hurling a barrage of insults and threats their way.
                            "[color=blue]Sounds to me like it wants some more.[/color]" comments one of them.
                            "[color=green]Isn't your uncle a horse? I think I once saw him pee for a minute straight. Let's go get him![/color]"
                        [/p]
                        [p]
                            With that being said, the boys rush off, presumably to find some adult to help them pick on the [b]kobold trapped in the well[/b],
                            You scream for them to come back, to stop playing around and to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                            You don't really know what to do.
                            If they [i]do[/i] end up getting that [i]horse[/i] they were talking about, the adult might be smart enough to get you out of here.
                            On the other hand, if he's as sadistic as his brother's son is, then you might not want to stick around to wait for his [i]assistance[/i].
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Halfway through conceiving an intricate escape plan concerning your tail and a star-shaped rock of some kind,
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\help\HamletWellScold.js

// scenes\HamletDay2\HamletWell\bottom\climb\HamletWellClimbRelent.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbRelent(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellClimbUpChoice.GIVE;
    var reqController = ctrl.climbUp;
    var subController = ctrl.preContinue;
    var changeController = ctrl.climbUpRelent;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var rope = arrivalChoice === HamletWellArrivalChoice.ROPE;
        var toReturn = `[p]
                            This is dangerous.
                            The further up you go, the more likely you'll be to [b]severely[/b] hurt yourself when you inevitably fuck up.
                            Growing ever more exhausted, you doubt it'll take long for you to [i]slip and fall[/i], or to pick another unstable rock.
                            You've already gotten lucky, and managed to prevent yourself from falling down [i]once[/i].
                            You don't want to keep testing fate.
                        [/p]
                        [p]
                            Letting out a loud, exacerbating sigh, you begin to climb back down the
                            well${wanted ? `, just like before${rope ? `, but this time without a rope` : ``}` : ``}.
                            ${!rocky ? `You've done this already, a fact that significantly boosts confidence in your climbing abilities.
                            Still, your journey is not without peril.` : `You hope you can go down the well [i]without[/i] falling this time around.
                            The shoddy cobblestone wall you're scaling isn't making this any easier for you, though.`}
                        [/p]
                        [p]
                            The earlier near-fall has made you somewhat paranoid.
                            You question every step you take, thoroughly testing every stone before grabbing it with your hand or placing your foot down upon it.
                            While being diligent makes the entire ordeal a bit [i]safer[/i], it also complicates things.
                            Entire paths which you would have taken without a doubt before are suddenly deemed too hazardous by your frightened mind.
                            You find yourself having to [b]stretch[/b] your body a lot more than usual to be able to [b]reach[/b] [i]safer[/i] points,
                            to put your aching sense of self-preservation at ease.
                        [/p]
                        [p]
                            Despite needing to test the very limits of how far you can extend your body, you manage to make it back down to the cold water without falling down.
                            You slip back into the cold liquid, to give your aching limbs a bit of much needed rest.
                            Even if you didn't manage to escape the well, sure was one hell of a workout.
                            You hope you'll be able to make it out of here alive, so you can put your newfound flexibility to use.
                        [/p]
                        [p]
                            Right as you were starting to consider other avenues of escape, a loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\climb\HamletWellClimbRelent.js

// scenes\HamletDay2\HamletWell\bottom\climb\keep\HamletWellKeepClimbingSucceed.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellKeepClimbingSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.climbUpSucceed;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.escapedClimb = true;
        var toReturn = `[p]
                            You need to keep going.
                            This might be your only way out, and you can't give up just because of a single bad thing happening.
                            Besides, you're already halfway to the top.
                            It'd be a darn [b]shame[/b] to quit now!
                            The way down would be as much of a climb as the way up is.
                            Plus, you're far more motivated by the thought of being [b]freed[/b] from this [i]watery prison[/i]
                            than you are by the premise of being stuck at the bottom [i]again[/i].
                        [/p]
                        [p]
                            It's decided, then.
                            You have to reach the top, no matter how tired or worn out your muscles may be.
                            You raise your arm to a different rock on the same level as the one that broke off a minute ago.
                            Then, the unexpected happens.
                            Like the one before it, this stone, too, breaks from the wall!
                            You are thrown off balance a second time, feeling even more startled than before.
                            You would never have expected two [b]adjacent[/b] rocks to [b]both[/b] be loose!
                        [/p]
                        [p]
                            Time itself seems to slow down as adrenaline floods your system.
                            You can't keep your balance on the shaky rock both your feet are on.
                            You need something new to grab onto, and you need it quick.
                            Looking upwards, you see two stones in the perfect position to hang off of.
                            They're far too high up for you to be able to reach them, though.
                            There's only one answer.
                            Only one thing you can do.
                        [/p]
                        [p]
                            With a soft growl, you [b]leap[/b] upwards, mere [b]moments[/b] before losing your balance completely.
                            Impressing even yourself, you manage to grab onto both of the rocks you were ogling earlier,
                            suspending your entire weight by your arms, while your legs fail to find support.
                            Adrenaline fueling your actions,
                            you amaze yourself further by clambering upwards using nothing but sheer armstrength to hoist your body up onto the next set of grabbable stones,
                            allowing your feet to rest on the rocks you jumped to, and bringing you a whole lot closer to your goal of escaping the well.
                        [/p]
                        ${global.ui.condSucc(`Agility and strength greater than 5`)}
                        [p]
                            You decide to keep climbing, before your sudden burst of strength fades.
                            A few minutes later, you emerge from the well, lifting yourself up and over the stone wall.
                            As adrenaline fades from your system, you collapse on the ground, all four of your limbs completely spent,
                            even your [b]tail[/b] feeling exhausted from the intensive, heart-rattling climb.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have escaped the well!
                                [/b]
                            [/c]
                        [/p]
                        [p]
                            You roll onto your back, spread eagle, breathing heavily, staring at the clear sky which you are grateful to see fully once more.
                            That was [b]hard[/b].
                            You didn't even [b]know[/b] you could do some of the things you did.
                            You thought you were going to die.
                            You only [b]barely[/b] made it out alive by the skin of your teeth.
                            In a weird way, however, the rush of excitement you felt when that rock broke off was [b]exhilarating[/b].
                            Defying death was just what you needed to take your mind off of Seki.
                            Maybe you should try that again sometimes.
                            Worst case scenario, you'll meet the old bird in the afterlife.
                        [/p]
                        [p]
                            After a small recovery period, you rise to your spent feet, wisely refraining from leaning against the well.
                            While your limbs are still aching from the extreme strain you put them under, and your heart is still reeling from the intense stress,
                            you feel like you're fit enough to continue on your journey to Varanar.
                            A bit of walking might put both your legs and your mind at ease, and your arms will appreciate a bit of inactivity.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\climb\keep\HamletWellKeepClimbingSucceed.js

// scenes\HamletDay2\HamletWell\bottom\climb\keep\HamletWellKeepClimbingFail.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellKeepClimbingFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.climbUpFail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You need to keep going.
                            This might be your only way out, and you can't give up just because of a single bad thing happening.
                            Besides, you're already halfway to the top.
                            It'd be a darn [b]shame[/b] to quit now!
                            The way down would be as much of a climb as the way up is.
                            Plus, you're far more motivated by the thought of being [b]freed[/b] from this [i]watery prison[/i]
                            than you are by the premise of being stuck at the bottom [i]again[/i].
                        [/p]
                        [p]
                            It's decided, then.
                            You have to reach the top, no matter how tired or worn out your muscles may be.
                            You raise your arm to a different rock on the same level as the one that broke off a minute ago.
                            Then, the unexpected happens.
                            Like the one before it, this stone, too, breaks from the wall!
                            You are thrown off balance a second time, feeling even more startled than before.
                            You would never have expected two [b]adjacent[/b] rocks to [b]both[/b] be loose!
                        [/p]
                        [p]
                            You try to reach for a new gripping point, much like you did before,
                            but this time you [b]aren't[/b] so lucky as to be able to simply grab a new rock.
                            You manage to stay put, balancing only on your feet, for just a few seconds more.
                            Time itself seems to slow down, as you tumble backwards, falling from the wall.
                        [/p]
                        ${global.ui.condFail(ctrl.misc.strength() < 6 ? `Strength below 6` : `Agility below 6`)}
                        [p]
                            Instinctively, to try to prevent yourself from [b]scraping[/b] against the well's rocky interior,
                            you kick yourself off from the ledge you were standing on at the very last moment.
                            Bad idea.
                            Due to the space you're in being so [b]confined[/b],
                            you end up harshly [b]bashing[/b] the soft back of your head against the other side of the well.
                            Your vision goes black.
                            You pass out, your limp body plummeting down into the cold water below.
                        [/p]
                        [hl]
                        [p]
                            You wearily open your eyes, what you can only imagine to be minutes, or maybe [b]hours[/b] after passing out and falling down.
                            You find yourself floating on your back on the surface of the frigid well water.
                            Your head hurts.
                            Your [b]everything[/b] hurts.
                            You slowly come to an upright swimming position, clutching the back of your skull.
                            Is that...[i]blood[/i] you feel?
                        [/p]
                        [p]
                            You don't get long to inspect your injuries, or even to contemplate what happened.
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake, clearing your foggy mind despite rousing a killer headache.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\HamletDay2\HamletWell\bottom\climb\keep\HamletWellKeepClimbingFail.js

// scenes\HamletDay2\HamletWell\bottom\climb\HamletWellKeepClimbing.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellKeepClimbing(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellClimbUpChoice.KEEP;
    var reqController = ctrl.climbUp;

    var toFail = new HamletWellKeepClimbingFail(ctrl);
    var toSuccess = new HamletWellKeepClimbingSucceed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.strength() > 5 && ctrl.misc.agility() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\HamletDay2\HamletWell\bottom\climb\HamletWellKeepClimbing.js

// scenes\HamletDay2\HamletWell\bottom\HamletWellClimbUp.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellFallChoice.CLIMB;
    var reqController = ctrl.down;
    var subController = ctrl.climbUp;
    var changeController = ctrl.climbUp;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new HamletWellClimbRelent(ctrl);
    var secondNext = new HamletWellKeepClimbing(ctrl);

    var firstChoice = HamletWellClimbUpChoice.GIVE;
    var secondChoice = HamletWellClimbUpChoice.KEEP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You didn't want to be in here to begin with. Falling down was an accident, and nothing more. `;
        arrivalDescriptor += `If you wanted to explore these depths, you'd have climbed down here on your own accord.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, but after the tiring climb downwards, all you really want to do is leave. `;
            arrivalDescriptor += `You've already proven yourself. There's no point to sticking around.`;
            if (rocky) {
                arrivalDescriptor = `You wanted to explore this place, but after your harrowing [i]entrance[/i], all you really want to do is leave.`;
            }
        }
        var toReturn = `[p]
                            Time to get out of this damp hole.
                            ${arrivalDescriptor}
                            You reach up as high as you can, grabbing onto a rock protruding from the wall,
                            you find a similar stone to place a foot on, and so you begin to climb from the water, and hopefully out of the well.
                        [/p]
                        [p]
                            Your wall-scaling, while exhausting, goes without a hitch.
                            That is, until you reach the approximate halfway point.
                            You are getting tired, weary, perhaps even [i]too[/i] weary to get to the top.
                            You grab one of the cobblestone walls' rocks, as you've done a dozen times before.
                            Then, you try to lift yourself up to the next set of grip-points, only for the lime holding the stone in place to fail to support your weight.
                            You accidentally tear it straight from the wall, and in surprise, you let it slip from your grasp.
                            It drops down into the water below with a siumple, yet fright-inspiring [i]plop[/i].
                        [/p]
                        [p]
                            The sudden lack of grip throws you off balance, and almost sends you tumbling back down the well${rocky ? ` again` : ``}.
                            It is only through sheer luck and well-honed reflexes that you manage to quickly take hold of a different anchor point to maintain your position.
                            While you didn't fall, you are thoroughly shaken.
                            The moment the rock dislodged, your heart skipped a beat.
                            Doubt floods your brain.
                            Maybe this wasn't the best idea after all.
                            Maybe you should go back down and find another way to escape, before you hurt yourself.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Give up</button>`;

        var tooltip = global.parser.parse(`You'd rather not hurt yourself trying to get out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Keep trying</button>`;

        var tooltip = global.parser.parse(`You're halfway there. Just a little bit more!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var HamletWellClimbUpChoice = {
    GIVE: 1,
    KEEP: 2
};

// END scenes\HamletDay2\HamletWell\bottom\HamletWellClimbUp.js

// scenes\HamletDay2\HamletWell\bottom\HamletWellHelp.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellHelp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellFallChoice.HELP;
    var reqController = ctrl.down;
    var subController = ctrl.help;
    var changeController = ctrl.help;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new HamletWellScold(ctrl);
    var secondNext = new HamletWellBeg(ctrl);

    var firstChoice = HamletWellHelpChoice.SCOLD;
    var secondChoice = HamletWellHelpChoice.BEG;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You didn't want to be in here to begin with.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, but after the tiring climb downwards,
                                all you can do is dread the thought that you might not be able to escape.`;
            if (rocky) {
                arrivalDescriptor = `You wanted to explore this place, but you couldn't even climb [i]down[/i] the well properly.`;
            }
        }
        var toReturn = `[p]
                            You don't think you can get out of this damp hole on your own.
                            ${arrivalDescriptor}
                            Your only option left is to shout for help, and hope somebody hears you.
                        [/p]
                        [p]
                            You take a deep breath, and [b]scream[/b] for aid.
                            Your shriek echoes throughout the well, but otherwise goes unanswered.
                            Doubt growing in the back of your mind, you shout for assistance a second time.
                            Once the reverberation comes to an end, you are left with silence.
                            Completely disheartened, you gaze upwards at the small bit of sky you can see, and let out a small sigh.
                        [/p]
                        [p]
                            Suddenly, a trio of silhouettes appear at the top of the well.
                            Are you imagining things?
                            You rub your eyes, thinking you were hit by a rock and are now hallucinating.
                            The figures persist.
                            They seem to be talking to one another, although you can't quite make out what they're saying.
                            Right as you were about to call out for aid a third time,
                            one of the three shouts into the well, with a shrill and juvenile sounding voice:
                            "[color=green]That's not a swimming pool, stupid lizard![/color]"
                        [/p]
                        [p]
                            All three of them burst out into laughter, loud enough for you to hear all the way down the well.
                            Judging by what little you can see of them, the pitch of their voices and their general attitude,
                            you guess these aren't [i]grown men[/i] you're talking to, but rather a group of young boys.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Scold</button>`;

        var tooltip = global.parser.parse(`Berate the kids for being so rude.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Beg</button>`;

        var tooltip = global.parser.parse(`Beg for help. Your life might be at stake!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var HamletWellHelpChoice = {
    SCOLD: 1,
    BEG: 2
};

// END scenes\HamletDay2\HamletWell\bottom\HamletWellHelp.js

// scenes\HamletDay2\HamletWell\bottom\HamletWellSwim.js

/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellSwim(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellFallChoice.SWIM;
    var reqController = ctrl.down;

    var toFail = new HamletWellScrape(ctrl);
    var toSuccess = new HamletWellPants(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.pants();
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }
        
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\HamletDay2\HamletWell\bottom\HamletWellSwim.js

// scenes\HamletDay2\HamletWell\fall\climb\HamletWellClimbSucceed.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbSucceed(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.climbSucceed;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After your depressing train of thoughts, you decide it's time to inspect the well more thoroughly.
                            There might be some coins at the bottom, and who knows what else you might find?
                            Some good old adventuring is exactly what you need to lift your spirits.
                        [/p]
                        [p]
                            You figure you might be able to scale down the cobblestone wall.
                            There's plenty of rocks sticking out, and like you noticed earlier,
                            the lime in between the stones is soft enough for you to carve your claws into, should the need arise.
                            While you're no expert in climbing, you've scaled many trees and even a couple of buildings before.
                            You're certain this'll go fine, but still, you're more than a little scared of the dark depths that await you.
                        [/p]
                        [p]
                            Gathering your courage, you let out a determined grunt.
                            Knights are fearless, and if you want to be one, you can't shy away from adventure.
                            You need to plunge head-first into danger!
                            Well, maybe not head-first, but you still need to go down the well,
                            if just to prove to yourself that you [b]do[/b] have what it takes to stop being a thief one day.
                        [/p]
                        [p]
                            You hop on top of the well's edge.
                            Facing away from the watering hole, you squat down.
                            With both your hands, you take hold of the rim of the cobblestone wall.
                            You let out a deep, nerve-soothing sigh.
                            Here you go.
                        [/p]
                        [p]
                            You lower your body into the watering hole, hanging off your hands until you can find a good place to put your feet.
                            At first, you only find [b]one[/b] rock sticking out within your reach, and it doesn't seem to be a very stable one.
                            Stretching your agile body to its very limits, however, you discover a second, far more stable stone platform just a few inches lower.
                            You place one of your feet down onto the rock, and with the first step made, you begin your descent proper.
                        [/p]
                        [p]
                            You deftly climb down the entire height of the circular cobblestone wall.
                            More than once do you find yourself in a perilous situation, but despite the well itself falling apart at the seams,
                            you manage to stick to the wall all the way to the bottom, where you lower your lithe frame into the cool water.
                            The water's too deep for you to stand up right.
                            Your gently kicking legs and your arms slowly rocking back and forth along the surface of the water keep your light frame afloat.
                            The damp, stale air at the bottom of the well is of poor quality,
                            but at least keeping yourself from sinking takes less effort than climbing down did.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 5`)}
                        [p]
                            You take a moment to recover from the strenuous climb.
                            You're glad and proud that you made it all the way down without falling.
                            A good display of flexibility, that you're certain not everyone can match.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you have to climb all the way back [b]up[/b] to get out of this place.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\climb\HamletWellClimbSucceed.js

// scenes\HamletDay2\HamletWell\fall\climb\HamletWellClimbFail.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbFail(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.climbFail;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.fell = true;
        var toReturn = `[p]
                            After your depressing train of thoughts, you decide it's time to inspect the well more thoroughly.
                            There might be some coins at the bottom, and who knows what else you might find?
                            Some good old adventuring is exactly what you need to lift your spirits.
                        [/p]
                        [p]
                            You figure you might be able to scale down the cobblestone wall.
                            There's plenty of rocks sticking out, and like you noticed earlier,
                            the lime in between the stones is soft enough for you to carve your claws into, should the need arise.
                            While you're no expert in climbing, you've scaled many trees and even a couple of buildings before.
                            You're certain this'll go fine, but still, you're more than a little scared of the dark depths that await you.
                        [/p]
                        [p]
                            Gathering your courage, you let out a determined grunt.
                            Knights are fearless, and if you want to be one, you can't shy away from adventure.
                            You need to plunge head-first into danger!
                            Well, maybe not head-first, but you still need to go down the well,
                            if just to prove to yourself that you [b]do[/b] have what it takes to stop being a thief one day.
                        [/p]
                        [p]
                            You hop on top of the well's edge.
                            Facing away from the watering hole, you squat down.
                            With both your hands, you take hold of the rim of the cobblestone wall.
                            You let out a deep, nerve-soothing sigh.
                            Here you go.
                        [/p]
                        [p]
                            You lower your body into the watering hole, hanging off your hands until you can find a good place to put your feet.
                            There's only [b]one[/b] rock sticking out within your reach, and it doesn't seem to be a very stable one.
                            Darnit, if only you were a little bit bigger!
                            Fearfully, you place one of your feet down onto the unsteady stone, which shifts around ever so slightly.
                            Still, it holds.
                            For now.
                        [/p]
                        [p]
                            As you move one of your hands from the rim of the well in search of a lower place to put it,
                            the rock under your foot suddenly gives way, breaking from the wall and falling down!
                            Your let out a fearful, surprised yelp.
                            Your foot no longer supported, you find yourself hanging from only a single hand, your claws digging into the rim of the well.
                            It's not enough.
                            You can feel your fingers slipping away.
                            You try to bring your other hand up again, to return to hanging off the edge with eight digits instead of four.
                            Before you manage to strengthen your hold, however, your fingers give way to gravity's relentless pull.
                            Your last bit of grip lost, you fall back-first into the pitch-black darkness of the well.
                        [/p]
                        ${global.ui.condFail(`Agility below 6`)}
                        [p]
                            You panic, [b]screaming[/b] in terror, thinking this might be the end of you.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud [b]splash[/b] as you plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your back bumps against the ground at the very base of the well.
                            Luckily, you quickly manage to find your way back up to surface of the water.
                        [/p]
                        [p]
                            Emerging from the ice-cold liquid, you immediately begin coughing up the watery contents of your respiratory system.
                            It's like a drink accidentally shot down the wrong hole, only ten times worse.
                            After agonizingly [b]vomiting[/b] water from your trachea, you resume your coughing fit.
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The damp, stale air at the bottom of the well is of poor quality, but at least with the liquid expelled from your lungs, you can breathe again.
                        [/p]
                        [p]
                            The rock you put your foot on broke off, leading to you falling down the well.
                            An unfortunate spell of bad luck that nearly cost you your life.
                            If it weren't for the water cushioning your fall, you'd have been a [b]dead[/b] lizard by now.
                            You didn't die, though.
                            Not yet, anyway.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole. Surely you won't fall [b]twice[/b], right?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\climb\HamletWellClimbFail.js

// scenes\HamletDay2\HamletWell\fall\HamletWellClimb.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimb(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellArrivalChoice.CLIMB;
    var reqController = ctrl.arrival;

    var toFail = new HamletWellClimbFail(ctrl, firstNext, secondNext, thirdNext);
    var toSuccess = new HamletWellClimbSucceed(ctrl, firstNext, secondNext, thirdNext);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.agility() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }
        
        ctrl.bgm.loop();
        global.ui.imageBackground.hide();
        global.ui.applyTheme("hamlet_well");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\HamletDay2\HamletWell\fall\HamletWellClimb.js

// scenes\HamletDay2\HamletWell\fall\HamletWellRope.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellRope(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellArrivalChoice.ROPE;
    var reqController = ctrl.arrival;
    var subController = ctrl.down;
    var changeController = ctrl.rope;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.drowned = true;
        global.kobold.history.shared.well.fell = true;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            After your depressing train of thoughts, you decide it's time to inspect the well more thoroughly.
                            There might be some coins at the bottom, and who knows what else you might find?
                            Some good old adventuring is exactly what you need to lift your spirits.
                        [/p]
                        [p]
                            You grab your ${global.kobold.inventory.createItemWithTooltip(new Rope())}, hoping to scale down the well.
                            There isn't anything around to tie it to, though.
                            The cable attached to the well's bucket is simply coiled off to the side,
                            but you don't think your own ${global.kobold.inventory.createItemWithTooltip(new Rope())} is long enough to reach the very bottom.
                            Still, you'd rather trust something Seki sold you than a random cord that's probably been out here for [b]years[/b].
                        [/p]
                        [p]
                            Pondering the logistics of this situation for a few seconds, you spot the solution lying on the ground.
                            A chunk of cobblestone has broken off the side of the well.
                            You figure it's perfect for tying your ${global.kobold.inventory.createItemWithTooltip(new Rope())} around!
                            It [i]seems[/i] and [i]feels[/i] heavy enough to support your weight, although if it actually [i]will[/i] remains to be seen.
                        [/p]
                        [p]
                            You attach one end of your cable to the piece of rock-wall, and toss the other end down the well.
                            You cast your gaze downwards, but it's too dark to see the bottom.
                            You're sure your eyes'll adapt to the darkness once you're down there.
                            And if they don't, you can climb back out, and it'll be like nothing happened! 
                        [/p]
                        [p]
                            Gathering your courage, you let out a determined grunt.
                            Knights are fearless, and if you want to be one, you can't shy away from adventure.
                            You need to plunge head-first into danger!
                            Well, maybe not head-first, but you still need to go down the well,
                            if just to prove to yourself that you [b]do[/b] have what it takes to stop being a thief one day.
                        [/p]
                        [p]
                            You hop on top of the well's edge.
                            Facing away from the watering hole, you squat down.
                            With one hand, you tightly grip your ${global.kobold.inventory.createItemWithTooltip(new Rope())},
                            and with the other you take hold of the rim of the cobblestone wall.
                            You let out a deep, nerve-soothing sigh.
                            Here you go.
                        [/p]
                        [p]
                            You lower your body into the watering hole, distributing your weight evenly between the rope and the well itself.
                            To your pleasant surprise, everything seems to be holding!
                            You place your feet against the rock wall, and begin your descent.
                            The moment you let go of the edge of the well, however, something happens.
                        [/p]
                        [p]
                            Shifting your entire weight -- however light that may be -- onto the rope causes the rock you tied it to to [b]jerk[/b] forwards,
                            instantly dropping you down a couple of feet more.
                            [b]Oh no[/b]!
                            You yelp out in surprise, your heart beating a million times a minute, fearing for your very life.
                            You [b]knew[/b] you should have tested the chunk of cobblestone more thoroughly!
                            It [b]stopped moving[/b], for now, so you think it might be [i]trapped[/i] against the side of the well.
                            As long as nothing [i]breaks[/i], you should be fine.
                        [/p]
                        [p]
                            Adrenaline coursing through your system, you slowly and carefully begin to make your way back upwards.
                            Right as confidence resurges inside of your mind, as you believe that you're going to make it back up to the edge of the well,
                            that you're going to survive this frightening trial with only a near-heart attack to show for it,
                            a loud [b]crack[/b] resonates across the watering hole.
                            The lime-based cement is failing to hold together the well under the added stress of supporting your lightweight frame.
                        [/p]
                        [p]
                            You freeze in place, hoping that hanging still will prevent the circular wall from breaking further, but alas, it is too late.
                            After a few tense moments, the rock-like chunk you tied your rope to [b]breaks apart[/b] the ancient structure.
                            A considerable piece of cobblestone tears away from the rest,
                            and with nothing left to keep your rope-holding rock in place,
                            it gets pulled downwards by your weight, sealing your fate.
                            With nothing left to support you, you fall back-first into the well, your descent followed by several menacing rocks of varying sizes.
                        [/p]
                        [p]
                            You panic, [b]screaming[/b] in terror, thinking this might be the end of you.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            Even if you [b]did[/b] manage to slow yourself down, you'd just get hit by the debris.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud series of [b]splashes[/b] as you and the falling rocks both plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your back bumps against the ground at the very base of the well.
                            A large chunk of cobblestone heavily and painfully lands on your stomach, squishing you against the well's muddy base, pinning you in place.
                        [/p]
                        [p]
                            [c]
                                <a href="scenes/HamletDay2/HamletWell/img/drown-debris-${dick ? "m" : "f"}-full.png" target="_blank">
                                    <img class="sfw wideimage" src="scenes/HamletDay2/HamletWell/img/drown-debris-${dick ? "m" : "f"}.png" title="Illustration by ByondRAGE, colored by Nyumii">
                                </a>
                            [/c]
                        [/p]
                        [p]
                            After falling, you find yourself [b]drowning[/b].
                            Panicking, you put every ounce of effort into pushing the heavy rock off of you, to regain your freedom.
                            Your consciousness is rapidly fading due to lack of air.
                            The thing just won't budge!
                            As you can feel life itself starting to slip away from you, you finally manage to dislodge the stone from your abdomen,
                            shoving it to the side a tiny little bit, enough for you to slip out from underneath it.
                            You swim upright.
                            Your feet touch the muddy ground below.
                            In a last-ditch attempt at survival, with your very last shred of power, you kick off from the submerged dirt,
                            launching you towards the surface of the water.
                        [/p]
                        [p]
                            You emerge from the ice-cold liquid, and immediately begin coughing up the watery contents of your respiratory system.
                            Your barely active brain [b]begs[/b] for air, but you can't breathe, not until you've emptied your [b]burning[/b] lungs.
                            After agonizingly [b]vomiting[/b] water from your trachea, you can finally take a much-needed gasp of oxygen,
                            the blackness that had begun to envelop the edges of your vision slightly clearing.
                        [/p]
                        [p]
                            It's not enough.
                            You need [b]more[/b].
                            You need to [b]breathe[/b], lest this damned well become your watery grave still.
                            You hack up more water, taking deep breaths in between each coughing fit.
                            Slowly, but steadily, you recover from the harrowing ordeal you just went through,
                            your breathing stabilizing as liquid drains from your lungs.
                        [/p]
                        [p]
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            The damp, stale air at the bottom of the well is of poor quality, but it sure as hell beats drowning.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The water isn't [i]that[/i] deep.
                            You figure a tall human could stand in here, but you can't.
                        [/p]
                        [p]
                            The rock you tied your ${global.kobold.inventory.createItemWithTooltip(new Rope())} to came loose.
                            It slid against the well's edge, and after a little while, it ended up breaking the old construct.
                            An unfortunate series of events that nearly cost you your life.
                            You didn't die, though.
                            Not yet, anyway.
                        [/p]
                        [p]
                            Your ${global.kobold.inventory.createItemWithTooltip(new Rope())} is floating on the water's surface next to you.
                            It must have gotten untangled from the chunk you tied it to somewhere during or after the fall.
                            You pocket it once more.
                            While there's a bad memory attached to it now, it might still be useful later on.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.imageBackground.hide();
        global.ui.applyTheme("hamlet_well");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\HamletWellRope.js

// scenes\HamletDay2\HamletWell\fall\HamletWellWalk.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWalk(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellArrivalChoice.WALK;
    var reqController = ctrl.arrival;
    var subController = ctrl.down;
    var changeController = ctrl.walk;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.drowned = true;
        global.kobold.history.shared.well.fell = true;
        var toReturn = `[p]
                            After your depressing train of thoughts, you'd rather not hang around this place for much longer.
                            You'd hoped the well could draw your mind away from your elderly bird friend, but alas,
                            it only ended up making you think of him even more.
                            In fact, the entire hamlet reminds you of Seki.
                            You remember how you used to refer to this place as [i]Seki's village[/i].
                            Good times.
                        [/p]
                        [p]
                            You let out a loud sigh.
                            With a heavy heart, you decide to leave the hamlet.
                            The first step you take, however, your foot lands atop something uneven and unsteady!
                            You accidentally step on top of a broken off chunk of the cobblestone well,
                            and before you manage to recover your balance, the rock slides out from underneath you along the slightly muddy ground.
                        [/p]
                        [p]
                            Thrown off balance further, you recoil to the rear.
                            Your butt bumping against the well, you attempt to grab onto it,
                            to stabilize yourself against its rocky, waist-high exterior, but it's too late.
                            You fall backwards, over the edge of the well, tumbling head-first into pitch-black darkness before you even know what's going on.
                        [/p]
                        [p]
                            You panic, [b]screaming[/b] in terror, fearing for your very life.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud [b]splash[/b] as you plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your head bumps against the ground at the very base of the well,
                            hard enough to significantly daze you.
                        [/p]
                        [p]
                            [c]
                                <a href="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}-full.png" target="_blank">
                                    <img class="sfw wideimage" src="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}.png" title="Illustration by ByondRAGE, colored by Nyumii">
                                </a>
                            [/c]
                        [/p]
                        [p]
                            After falling, you find yourself [b]drowning[/b].
                            In your disoriented panic, you can't tell top from bottom.
                            You twist and turn in an attempt to get yourself upright, your consciousness,
                            already diminished from hitting your head, rapidly fading due to lack of air.
                            Just as you can feel life itself starting to slip away from you, one of your feet touches the muddy ground below.
                            In a last-ditch attempt at survival, with your very last ounce of power, you kick off from the submerged dirt,
                            launching you towards the surface of the water.
                        [/p]
                        [p]
                            You emerge from the ice-cold liquid, and immediately begin coughing up the watery contents of your respiratory system.
                            Your barely active brain [b]begs[/b] for air, but you can't breathe, not until you've emptied your [b]burning[/b] lungs.
                            After painfully [b]vomiting[/b] water from your trachea, you can finally take a much-needed gasp of oxygen,
                            the blackness that had begun to envelop the edges of your vision slightly clearing.
                        [/p]
                        [p]
                            It's not enough.
                            You need [b]more[/b].
                            You need to [b]breathe[/b], lest this damned well become your watery grave still.
                            You hack up more water, taking deep breaths in between each coughing fit.
                            Slowly, but steadily, you recover from the harrowing ordeal you just went through,
                            your breathing stabilizing as liquid drains from your lungs.
                        [/p]
                        [p]
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            The damp, stale air at the bottom of the well is of poor quality, but it sure as hell beats drowning.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The water isn't [i]that[/i] deep.
                            You figure a tall human could stand in here, but you can't.
                        [/p]
                        [p]
                            You tripped, and you fell.
                            Dumb mistake.
                            It nearly cost you your life, but you didn't die.
                            Not yet, anyway.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.imageBackground.hide();
        global.ui.applyTheme("hamlet_well");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\HamletWellWalk.js

// scenes\HamletDay2\HamletWell\fall\water\HamletWellWaterSucceed.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWaterSucceed(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.waterSucceed;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.fell = true;
        global.kobold.history.shared.well.drowned = true;
        global.kobold.history.shared.well.drankWater = true;
        var toReturn = `[p]
                            After your depressing train of thoughts, you need something, [b]anything[/b] to take your mind off of Seki.
                            Desperately looking for a way to forget about your friend for a while, you turn to the rope disappearing into the well.
                            Drawing water might be a good way to pass the time, and honestly, you could use a refreshing drink.
                        [/p]
                        [p]
                            You grab the rope, and give it a firm [b]yank[/b].
                            It doesn't budge.
                            The bucket must be stuck on something, or maybe it's just too heavy for you to lift.
                            Determined to get some water, you dig your claws into the ground and lean back,
                            tugging at the rope with not just your arms, but your entire weight, however little that may be.
                        [/p]
                        [p]
                            Your new tactic proves to be effective!
                            After a bit of pulling, the bucket finally shoots free, causing you to fall on your behind.
                            Luckily, you're strong enough to keep the filled bucket lifted through sheer arm-strength alone.
                            You scamper to your feet without letting go of the rope, and begin to painstakingly hoist the container upwards, one tug at a time.
                        [/p]
                        ${global.ui.condSucc(`Strength greater than 5`)}
                        [p]
                            Success!
                            After a long and arduous game of tug of war against gravity itself, a bucket of fresh well-water appears near the edge of the well.
                            You inch both your hands towards it, along the length of the rope,
                            until you can take hold of the bucket with both of your hands, to lift it out of the well proper.
                            You did it!
                            It was hard, but you've managed to draw water from the well.
                            Your reward is a bucket of fresh, cool water.
                            Now for the fun part: to drink it!
                        [/p]
                        [p]
                            You bring the rim of the bucket to your lips.
                            Opening your muzzle, you tilt both your head and the container upwards, letting the refreshing liquid [b]gush[/b] into your open maw,
                            greedily gulping it down like the exhausted lizard you are.
                            After emptying about half of the bucket, a lot of which was spilled over your chest instead of disappearing down your throat,
                            you set the considerably lighter wooden container down on the ground.
                        [/p]
                        [p]
                            Suddenly, your sight goes kind of blurry.
                            You feel woozy, and your body rocks from side to side as though you're drunk!
                            You stumble about, trying to find the edge of the well, so you can take a seat until the feeling passes.
                            While you do manage to find the rim of the watering hole, a fresh wave of drowsiness washes over you.
                            Your balance disturbed, you fall backwards, over the edge of the well,
                            tumbling head-first into pitch-black darkness before you even know what's going on.
                        [/p]
                        [p]
                            Adrenaline floods your system, seemingly counteracting the sudden onset of tiredness.
                            Panic quickly settles in.
                            You begin to [b]scream[/b] in terror, fearing for your very life.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud [b]splash[/b] as you plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your head bumps against the ground at the very base of the well,
                            hard enough to significantly daze you.
                        [/p]
                        [p]
                            [c]
                                <a href="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}-full.png" target="_blank">
                                    <img class="sfw wideimage" src="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}.png" title="Illustration by ByondRAGE, colored by Nyumii">
                                </a>
                            [/c]
                        [/p]
                        [p]
                            After falling, you find yourself [b]drowning[/b].
                            In your disoriented panic, you can't tell top from bottom.
                            You twist and turn in an attempt to get yourself upright, your consciousness,
                            already diminished from hitting your head, rapidly fading due to lack of air.
                            Just as you can feel life itself starting to slip away from you, one of your feet touches the muddy ground below.
                            In a last-ditch attempt at survival, with your very last ounce of power, you kick off from the submerged dirt,
                            launching you towards the surface of the water.
                        [/p]
                        [p]
                            You emerge from the ice-cold liquid, and immediately begin coughing up the watery contents of your respiratory system.
                            Your barely active brain [b]begs[/b] for air, but you can't breathe, not until you've emptied your [b]burning[/b] lungs.
                            After painfully [b]vomiting[/b] water from both your esophagus and your trachea, you can finally take a much-needed gasp of oxygen,
                            the blackness that had begun to envelop the edges of your vision slightly clearing.
                        [/p]
                        [p]
                            It's not enough.
                            You need [b]more[/b].
                            You need to [b]breathe[/b], lest this damned well become your watery grave still.
                            You hack up more water, taking deep breaths in between each coughing fit.
                            Slowly, but steadily, you recover from the harrowing ordeal you just went through,
                            your breathing stabilizing as liquid drains from your lungs.
                        [/p]
                        [p]
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            The damp, stale air at the bottom of the well is of poor quality, but it sure as hell beats drowning.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The water isn't [i]that[/i] deep.
                            You figure a tall human could stand in here, but you can't.
                        [/p]
                        [p]
                            One moment you were happily enjoying the spoils of your labor, the other you felt so sick you could hardly [b]stand[/b].
                            Was it the water?
                            You're swimming in the stuff right now, and it's not affecting you at all.
                            But then again, you've already thrown up the liquid you drank.
                            Maybe it only does it when it's ingested.
                            Or perhaps it just a momentary lapse of strength.
                            Regardless, your clumsiness nearly cost you your life.
                            You didn't die, though.
                            Not yet, anyway.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;
        
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\water\HamletWellWaterSucceed.js

// scenes\HamletDay2\HamletWell\fall\water\HamletWellWaterFail.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWaterFail(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.waterFail;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.drowned = true;
        global.kobold.history.shared.well.fell = true;
        var toReturn = `[p]
                            After your depressing train of thoughts, you need something, [b]anything[/b] to take your mind off of Seki.
                            Desperately looking for a way to forget about your friend for a while, you turn to the rope disappearing into the well.
                            Drawing water might be a good way to pass the time, and honestly, you could use a refreshing drink.
                        [/p]
                        [p]
                            You grab the rope, and give it a firm [b]yank[/b].
                            It doesn't budge.
                            The bucket must be stuck on something, or maybe it's just too heavy for you to lift.
                            Determined to get some water, you dig your claws into the ground and lean back,
                            tugging at the rope with not just your arms, but your entire weight, however little that may be.
                        [/p]
                        [p]
                            Your new tactic proves to be effective!
                            After a bit of pulling, the bucket finally shoots free, causing you to fall on your behind.
                            Then, something unexpected happens.
                            While your weight and all of the muscle power you could muster were sufficient to dislodge the water-container,
                            you aren't powerful enough to keep it lifted!
                        [/p]
                        ${global.ui.condFail(`Strength below 6`)}
                        [p]
                            Your hands still clinging to the rope, you are pulled forwards, towards the well.
                            Before you even realize what's going on, you find yourself yanked over the waist-height well-wall,
                            pulled into the depths of the watering hole.
                            You let go of the rope, but it's too late!
                            You're already falling, tumbling head-first into pitch-black darkness.
                        [/p]
                        [p]
                            You panic, [b]screaming[/b] in terror, fearing for your very life.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud [b]splash[/b] as you plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your head bumps against the ground at the very base of the well,
                            hard enough to significantly daze you.
                        [/p]
                        [p]
                            [c]
                                <a href="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}-full.png" target="_blank">
                                    <img class="sfw wideimage" src="scenes/HamletDay2/HamletWell/img/drown-disorient-${ctrl.misc.dick() ? "m" : "f"}.png" title="Illustration by ByondRAGE, colored by Nyumii">
                                </a>
                            [/c]
                        [/p]
                        [p]
                            After falling, you find yourself [b]drowning[/b].
                            In your disoriented panic, you can't tell top from bottom.
                            You twist and turn in an attempt to get yourself upright, your consciousness,
                            already diminished from hitting your head, rapidly fading due to lack of air.
                            Just as you can feel life itself starting to slip away from you, one of your feet touches the muddy ground below.
                            In a last-ditch attempt at survival, with your very last ounce of power, you kick off from the submerged dirt,
                            launching you towards the surface of the water.
                        [/p]
                        [p]
                            You emerge from the ice-cold liquid, and immediately begin coughing up the watery contents of your respiratory system.
                            Your barely active brain [b]begs[/b] for air, but you can't breathe, not until you've emptied your [b]burning[/b] lungs.
                            After painfully [b]vomiting[/b] water from your trachea, you can finally take a much-needed gasp of oxygen,
                            the blackness that had begun to envelop the edges of your vision slightly clearing.
                        [/p]
                        [p]
                            It's not enough.
                            You need [b]more[/b].
                            You need to [b]breathe[/b], lest this damned well become your watery grave still.
                            You hack up more water, taking deep breaths in between each coughing fit.
                            Slowly, but steadily, you recover from the harrowing ordeal you just went through,
                            your breathing stabilizing as liquid drains from your lungs.
                        [/p]
                        [p]
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            The damp, stale air at the bottom of the well is of poor quality, but it sure as hell beats drowning.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The water isn't [i]that[/i] deep.
                            You figure a tall human could stand in here, but you can't.
                        [/p]
                        [p]
                            You'd managed to lift the water bucket out of the water, only for it to fall back down, pulling you along with it.
                            You should have known you weren't strong enough to operate a man-made well.
                            Your mistake nearly cost you your life, but you didn't die.
                            Not yet, anyway.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

// END scenes\HamletDay2\HamletWell\fall\water\HamletWellWaterFail.js

// scenes\HamletDay2\HamletWell\fall\HamletWellWater.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWater(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellArrivalChoice.WATER;
    var reqController = ctrl.arrival;

    var toFail = new HamletWellWaterFail(ctrl, firstNext, secondNext, thirdNext);
    var toSuccess = new HamletWellWaterSucceed(ctrl, firstNext, secondNext, thirdNext);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return ctrl.misc.strength() > 5;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.imageBackground.hide();
        global.ui.applyTheme("hamlet_well");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\HamletDay2\HamletWell\fall\HamletWellWater.js

// scenes\HamletDay2\HamletWell\arrival\HamletWellArrival.js

/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";

    var childFirstNext = new HamletWellSwim(ctrl);
    var childSecondNext = new HamletWellClimbUp(ctrl);
    var childThirdNext = new HamletWellHelp(ctrl);

    var firstNext = new HamletWellWalk(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var secondNext = new HamletWellWater(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var thirdNext = new HamletWellClimb(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var fourthNext = new HamletWellRope(ctrl, childFirstNext, childSecondNext, childThirdNext);

    var firstChoice = HamletWellArrivalChoice.WALK;
    var secondChoice = HamletWellArrivalChoice.WATER;
    var thirdChoice = HamletWellArrivalChoice.CLIMB;
    var fourthChoice = HamletWellArrivalChoice.ROPE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            In an attempt to take your mind off of Seki, you turn your attention to the well.
                            It's a small, circular structure that reaches slightly above your waist.
                            The cobblestone it's made of looks pretty shabby, like it's fit to collapse any minute now.
                            Then again, judging by the ancient-looking moss clinging to the damp dirt on the northern end,
                            you figure the well's been around for a [b]very[/b] long time.
                            You probably won't look that good when you reach its age.
                        [/p]
                        [p]
                            If there's one thing humans are good at, it's building things that last.
                            From gigantic stone walls surrounding their enormous cities, to intricately engraved cathedral-windows.
                            Compared to the slums and sheds kobolds live in, even the simplest of human homes could pass for a [b]palace[/b].
                            Fit for [b]royalty[/b], if your kind actually [i]had[/i] rulership beyond petty crime lords.
                            Maybe that's why your species never learned to construct things beyond small cabins.
                            There isn't any need for big homes when everyone is [i]equally unimportant[/i].
                            Or maybe it's the other way around?
                        [/p]
                        [p]
                            You, personally, have never really built anything.
                            You kind of [i]stumbled upon[/i] the shack that you live in,
                            and you don't have need for anything but a place to rest your weary head at night.
                            You imagine building things isn't all that easy, especially not for someone your size.
                            Even if you somehow made it through the whole [i]planning[/i] phase,
                            the sheer amount of physical work needed to build something is far too much for any one kobold to handle.
                            And good luck getting an entire team to work together for more than a couple of days.
                        [/p]
                        [p]
                            What were you thinking about again?
                            Before you started [i]daydreaming[/i]?
                            Oh right, the well.
                        [/p]
                        [p]
                            You leisurely pace a few laps around it, inspecting the old structure.
                            A rope lies coiled next to it, one end disappearing into the watering hole's pitch-blackness.
                            The irregular stones the well is made of vary heavily in size.
                            Some are as big as your fist, others are but mere pebbles.
                            They're tied together by a flimsy lime-mixture.
                            Heck, you could probably tear the entire thing apart using nothing but your claws.
                        [/p]
                        [p]
                            You somehow doubt the locals would appreciate you [i]demolishing[/i] their convenient supply of water, though.
                            Then again, the river isn't [i]that[/i] far off.
                            Those lazy farmers getting fat off their own produce could definitely use the extra exercise.
                            Maybe you'll come back here next week for some mindless, stress-relieving vandalism.
                            If what Seki says is true, you'll no longer have to worry about [i]inconveniencing[/i] him by then,
                            and you'll undoubtedly have plenty of frustration to work out on inanimate objects.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 170px;">Walk away</button>`;

        var tooltip = global.parser.parse(`The well doesn't interest you anymore. Now it just makes you sad.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 170px;">Draw water</button>`;

        var tooltip = global.parser.parse(`Attempt to fetch some water from the bottom of the pit.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 205px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 170px;">Climb down</button>`;

        var tooltip = global.parser.parse(`Scale down the rocky well wall.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var check = ctrl.misc.hasMisc(new Rope());
        var disabled = subController.has() || !check ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 170px;">Use rope</button>`;

        var tooltip = global.parser.parse(`Use your rope to climb down into the well.`);
        if (!check) {
            tooltip = global.parser.parse(`You don't have a rope to climb down with.`);
        }

        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildThirdChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFourthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.show("scenes/HamletDay2/HamletWell/img/wellbackground.png");
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
    };
}

var HamletWellArrivalChoice = {
    WALK: 1,
    WATER: 2,
    CLIMB: 3,
    ROPE: 4
};

// END scenes\HamletDay2\HamletWell\arrival\HamletWellArrival.js

// scenes\HamletDay2\HamletWell\HamletWellController.js

/**
 * Controller for the Well scene.
 * @param {string} sceneId The id of the scene.
 */
function HamletWellController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = true;
    this.nextSceneName = "UndergroundCave";
    this.nextFolderName = "HamletDay2";
    this.varanarSceneName = "NightTwo";
    this.varanarFolderName = "Varanar";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");

    this.rope = new ChangeController(id, "rope", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(15, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(17, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -3),
            new Change("Squished by debris", "Health", -5),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Climbing", "Stamina", -3),
            new Change("Screaming", "Stamina", -2),
            new Change("Pushing rock off", "Stamina", -4),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        changes.concat(
                [new Change("Used rope", global.kobold.inventory.createItemWithTooltip(new Rope(), true), -1),
                    new Change("Recovered rope", global.kobold.inventory.createItemWithTooltip(new Rope(), true), +1)]);

        return global.ui.change.buildNotification(changes);
    });

    this.walk = new ChangeController(id, "walk", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(10, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.waterFail = new ChangeController(id, "waterFail", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(12, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Tugging", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.waterSucceed = new ChangeController(id, "waterSucceed", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(3, "Stuck in the well");
        global.kobold.status.stamina.decrease(12, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Drew water", "Sanity", +5),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Tugging", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.climbFail = new ChangeController(id, "climbFail", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(7, "Falling into the well");
        global.kobold.status.mental.decrease(3, "Stuck in the well");
        global.kobold.status.stamina.decrease(6, "Falling into the well");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Water in lungs", "Health", -3),
            new Change("Fell in well", "Sanity", -6),
            new Change("Survived", "Sanity", +3),
            new Change("Climbing", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Coughing", "Stamina", -2)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.climbSucceed = new ChangeController(id, "climbSucceed", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.mental.increase(7, "Climbing into the well");
        global.kobold.status.stamina.decrease(12, "Climbing into the well");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Climbed down", "Sanity", +10),
            new Change("Stuck", "Sanity", -3),
            new Change("Climbing", "Stamina", -12)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.down = new ChoiceController(id, "down");

    this.pants = new ChangeController(id, "pants", function () {
        that.misc.pants();
        global.kobold.status.mental.increase(5, "Finding gold in the well");
        global.kobold.status.stamina.decrease(6, "Diving");
        global.kobold.inventory.coins = global.kobold.inventory.coins + 37;
        global.kobold.inventory.equipment.strip(SlotEnum.PANTS);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Lost pants", "Sanity", -2),
            new Change("Found gold", "Sanity", +7),
            new Change("Diving", "Stamina", -6),
            new Change("Found gold", "Coins", +37),
            new Change("Ripped pants", global.kobold.inventory.createItemWithTooltip(that.misc.pants(), true), -1)
        ]);
    });

    this.scrape = new ChangeController(id, "scrape", function () {
        global.kobold.status.physical.decrease(15, "Scraped leg");
        global.kobold.status.mental.decrease(10, "Pain");
        global.kobold.status.stamina.decrease(3, "Diving");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Scraped", "Health", -15),
            new Change("Pain", "Sanity", -10),
            new Change("Diving", "Stamina", -3)
        ]);
    });

    this.climbUp = new ChangeController(id, "climbUp", function () {
        global.kobold.status.mental.decrease(5, "Almost fell down");
        global.kobold.status.stamina.decrease(15, "Climbing up");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Almost fell", "Sanity", -5),
            new Change("Climbing up", "Stamina", -15)
        ]);
    });

    this.climbUpRelent = new ChangeController(id, "climbUpRelent", function () {
        global.kobold.status.mental.increase(4, "Still stuck");
        global.kobold.status.stamina.decrease(8, "Climbing down");
        global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stopped before getting hurt", "Sanity", +6),
            new Change("Still stuck", "Sanity", -2),
            new Change("Climbing down", "Stamina", -8),
            new Change("Good workout", "Agility", +1)
        ]);
    });

    this.climbUpFail = new ChangeController(id, "climbUpFail", function () {
        global.kobold.status.physical.decrease(25, "Hit head against wall");
        global.kobold.status.mental.decrease(16, "Seriously hurt");
        global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hit head", "Health", -15),
            new Change("Knocked unconscious", "Health", -10),
            new Change("Fell down", "Sanity", -6),
            new Change("Seriously hurt", "Sanity", -10),
            new Change("Hit head", "Intelligence", -1)
        ]);
    });

    this.climbUpSucceed = new ChangeController(id, "climbUpSucceed", function () {
        global.kobold.status.physical.decrease(5, "Overexertion");
        global.kobold.status.mental.increase(20, "Escaped the well");
        global.kobold.status.stamina.decrease(20, "Intensive climbing");
        global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Overexertion", "Health", -5),
            new Change("Impressed self", "Sanity", +10),
            new Change("Escaped the well", "Sanity", +10),
            new Change("Intensive climbing", "Stamina", -20),
            new Change("Pushed your limits", "Endurance", +1)
        ]);
    });

    this.help = new ChangeController(id, "help", function () { // Do NOT change key, used in shared history.
        global.kobold.history.shared.well.metBoys = true;
        global.kobold.status.mental.increase(2, "Help?");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Potential help", "Sanity", +2)
        ]);
    });

    this.helpScold = new ChangeController(id, "helpScold", function () {
        global.kobold.status.mental.decrease(19, "Rude children");
        global.kobold.stats.decreaseStat(StatsEnum.CHARISMA, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Peed on (kind of)", "Sanity", -10),
            new Change("Laughed at", "Sanity", -2),
            new Change("Frustration", "Sanity", -7),
            new Change("Botched negotiations", "Charisma", -1)
        ]);
    });

    this.helpBegFail = new ChangeController(id, "helpBegFail", function () {
        global.kobold.status.mental.decrease(13, "Mean kids");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Insulted", "Sanity", -1),
            new Change("Laughed at", "Sanity", -2),
            new Change("Left to die", "Sanity", -10)
        ]);
    });

    this.helpBegSucceed = new ChangeController(id, "helpBegSucceed", function () {
        global.kobold.status.mental.increase(20, "Shown kindness by a stranger");
        global.kobold.status.stamina.decrease(10, "Climbed out of the well");
        global.kobold.stats.increaseStat(StatsEnum.LUCK, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped", "Sanity", +20),
            new Change("Climbing", "Stamina", +10),
            new Change("Saved by a stranger", "Luck", +1)
        ]);
    });

    this.preContinue = new ChoiceController(id, "preContinue");

    this.bgm = new AudioController(id, "res/audio/effects/waterdrip.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

var HamletWellFallChoice = {
    SWIM: 1,
    CLIMB: 2,
    HELP: 3
};

// END scenes\HamletDay2\HamletWell\HamletWellController.js

// scenes\HamletDay2\HamletWell\HamletWell.js

/**
 * Well in the hamlet.
 */
function HamletWell() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "HamletWell";
    var sceneName = "Hamlet, the Well";
    var sceneSubfolder = "HamletDay2";
    var ctrl = new HamletWellController(sceneId);
    var arrival = new HamletWellArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]hamlet[/t]`);
        tab += global.parser.parse(`[st]The well[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new HamletWell();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\HamletDay2\HamletWell\HamletWell.js



// END SCENE HamletWell

